AccountServiceClient class

Account Service

Annotations
  • @GrpcServiceName.new('AccountService')

Constructors

AccountServiceClient(ClientChannel channel, {CallOptions? options, Iterable<ClientInterceptor>? interceptors})

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

$createCall<Q, R>(ClientMethod<Q, R> method, Stream<Q> requests, {CallOptions? options}) → ClientCall<Q, R>
inherited
$createStreamingCall<Q, R>(ClientMethod<Q, R> method, Stream<Q> requests, {CallOptions? options}) → ResponseStream<R>
inherited
$createUnaryCall<Q, R>(ClientMethod<Q, R> method, Q request, {CallOptions? options}) → ResponseFuture<R>
inherited
create(Account request, {CallOptions? options}) → ResponseFuture<Account>
Accounts: Create Account
delete(AccountId request, {CallOptions? options}) → ResponseFuture<Empty>
Accounts: Delete Account
follow(FollowRequest request, {CallOptions? options}) → ResponseFuture<FollowResponse>
get(AccountId request, {CallOptions? options}) → ResponseFuture<AccountInfo>
Accounts: Get Account
getProfile(AccountProfileRequest request, {CallOptions? options}) → ResponseFuture<AccountProfileInfo>
getPublicProfile(UUID request, {CallOptions? options}) → ResponseFuture<AccountPublicProfile>
getStatus(AccountStatusRequest request, {CallOptions? options}) → ResponseFuture<AccountStatusResponse>
Accounts: Get Account Status
list(AccountQuery request, {CallOptions? options}) → ResponseFuture<PageResult>
Accounts: List Accounts AccountHeader
listFollows(FollowQuery request, {CallOptions? options}) → ResponseFuture<PageResult>
Accounts: List Follows AccountHeader
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited
unFollow(UnFollowRequest request, {CallOptions? options}) → ResponseFuture<UnFollowResponse>
update(Account request, {CallOptions? options}) → ResponseFuture<Account>
Accounts: Update Account
verify(AccountVerificationRequest request, {CallOptions? options}) → ResponseFuture<AccountVerificationResponse>

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

defaultHost → const String
The hostname for this service.
oauthScopes → const List<String>
OAuth scopes needed for the client.