AdServiceBase class abstract

Annotations
  • @GrpcServiceName.new('AdService')

Constructors

AdServiceBase()

Properties

$name String
no setter
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

$addMethod(ServiceMethod method) → void
inherited
$lookupMethod(String name) → ServiceMethod?
inherited
$onMetadata(ServiceCall context) → void
Client metadata handler.
inherited
create(ServiceCall call, AdDetails request) Future<AdDetails>
create_Pre(ServiceCall $call, Future<AdDetails> $request) Future<AdDetails>
delete(ServiceCall call, StoredObjectId request) Future<Empty>
delete_Pre(ServiceCall $call, Future<StoredObjectId> $request) Future<Empty>
get(ServiceCall call, StoredObjectId request) Future<AdDetails>
get_Pre(ServiceCall $call, Future<StoredObjectId> $request) Future<AdDetails>
history(ServiceCall call, AdHistoryQuery request) Future<PageResult>
history_Pre(ServiceCall $call, Future<AdHistoryQuery> $request) Future<PageResult>
list(ServiceCall call, AdQuery request) Future<PageResult>
list_Pre(ServiceCall $call, Future<AdQuery> $request) Future<PageResult>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
notifyAdsReadyForReview(ServiceCall call, AccountId request) Future<Empty>
notifyAdsReadyForReview_Pre(ServiceCall $call, Future<AccountId> $request) Future<Empty>
status(ServiceCall call, AdsStatusRequest request) Future<AdsStatusResponse>
status_Pre(ServiceCall $call, Future<AdsStatusRequest> $request) Future<AdsStatusResponse>
toString() String
A string representation of this object.
inherited
update(ServiceCall call, AdDetails request) Future<AdDetails>
update_Pre(ServiceCall $call, Future<AdDetails> $request) Future<AdDetails>

Operators

operator ==(Object other) bool
The equality operator.
inherited