AdServiceClient class

Ad Service

Annotations
  • @GrpcServiceName.new('AdService')

Constructors

AdServiceClient(ClientChannel channel, {CallOptions? options, Iterable<ClientInterceptor>? interceptors})

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

$createCall<Q, R>(ClientMethod<Q, R> method, Stream<Q> requests, {CallOptions? options}) → ClientCall<Q, R>
inherited
$createStreamingCall<Q, R>(ClientMethod<Q, R> method, Stream<Q> requests, {CallOptions? options}) → ResponseStream<R>
inherited
$createUnaryCall<Q, R>(ClientMethod<Q, R> method, Q request, {CallOptions? options}) → ResponseFuture<R>
inherited
create(AdDetails request, {CallOptions? options}) → ResponseFuture<AdDetails>
delete(StoredObjectId request, {CallOptions? options}) → ResponseFuture<Empty>
get(StoredObjectId request, {CallOptions? options}) → ResponseFuture<AdDetails>
Ads: Get Ad
history(AdHistoryQuery request, {CallOptions? options}) → ResponseFuture<PageResult>
Ads: History AdHistory
list(AdQuery request, {CallOptions? options}) → ResponseFuture<PageResult>
Ads: List Ads AdDetails
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
notifyAdsReadyForReview(AccountId request, {CallOptions? options}) → ResponseFuture<Empty>
status(AdsStatusRequest request, {CallOptions? options}) → ResponseFuture<AdsStatusResponse>
toString() String
A string representation of this object.
inherited
update(AdDetails request, {CallOptions? options}) → ResponseFuture<AdDetails>
Ads: Update Ad

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

defaultHost → const String
The hostname for this service.
oauthScopes → const List<String>
OAuth scopes needed for the client.