AdDetails class

Available extensions

Constructors

AdDetails({StringValue? rowVersion, Ad? ad, Int32Value? totalViews, Int32Value? totalClicks, Credit? initialPrice, Timestamp? startDateTime, Timestamp? lastPriceReduction, Timestamp? endDateDate, AdDetails_AdExpirationAction? expirationAction, Iterable<SalesChannelInfo>? salesChannels, Credit? purchasePrice, Timestamp? expirationDateTime, DynamicPricing? dynamicPricing})
factory
AdDetails.fromBuffer(List<int> data, [ExtensionRegistry registry = $pb.ExtensionRegistry.EMPTY])
factory
AdDetails.fromJson(String json, [ExtensionRegistry registry = $pb.ExtensionRegistry.EMPTY])
factory

Properties

getter/setter pair
dynamicPricing DynamicPricing
getter/setter pair
endDateDate ↔ Timestamp
getter/setter pair
expirationAction AdDetails_AdExpirationAction
getter/setter pair
expirationDateTime ↔ Timestamp
getter/setter pair
hashCode int
Calculates a hash code based on the contents of the protobuf.
no setterinherited
info_ → BuilderInfo
no setter
initialPrice Credit
getter/setter pair
isFrozen bool
Returns true if this message is marked read-only. Otherwise false.
no setterinherited
lastPriceReduction ↔ Timestamp
getter/setter pair
purchasePrice Credit
UserId ScannedBy = 14;//Moved to object
getter/setter pair
rowVersion ↔ StringValue
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
salesChannels → PbList<SalesChannelInfo>
no setter
startDateTime ↔ Timestamp
getter/setter pair
totalClicks ↔ Int32Value
getter/setter pair
totalViews ↔ Int32Value
getter/setter pair
unknownFields → UnknownFieldSet
no setterinherited

Methods

addExtension(Extension extension, Object? value) → void
Adds an extension field value to a repeated field.
inherited
check() → void
Throws a StateError if the message has required fields without a value.
inherited
clear() → void
Clears all data that was set in this message.
inherited
clearAd() → void
clearDynamicPricing() → void
clearEndDateDate() → void
clearExpirationAction() → void
clearExpirationDateTime() → void
clearExtension(Extension extension) → void
Clears an extension field and also removes the extension.
inherited
clearField(int tagNumber) → void
Clears the contents of a given field.
inherited
clearInitialPrice() → void
clearLastPriceReduction() → void
clearPurchasePrice() → void
clearRowVersion() → void
clearStartDateTime() → void
clearTotalClicks() → void
clearTotalViews() → void
clone() AdDetails
Creates a deep copy of the fields in this message.
copyWith(void updates(AdDetails)) AdDetails
Apply updates to a copy of this message.
createEmptyInstance() AdDetails
Creates an empty instance of the same message type as this.
deepCopy() → T

Available on T, provided by the GeneratedMessageGenericExtensions extension

Returns a writable deep copy of this message.
ensureAd() Ad
ensureDynamicPricing() DynamicPricing
ensureEndDateDate() → Timestamp
ensureExpirationDateTime() → Timestamp
ensureInitialPrice() Credit
ensureLastPriceReduction() → Timestamp
ensurePurchasePrice() Credit
ensureRowVersion() → StringValue
ensureStartDateTime() → Timestamp
ensureTotalClicks() → Int32Value
ensureTotalViews() → Int32Value
extensionsAreInitialized() bool
inherited
freeze() → GeneratedMessage
Make this message read-only.
inherited
getDefaultForField(int tagNumber) → dynamic
Returns the default value for the given field.
inherited
getExtension(Extension extension) → dynamic
Returns the value of extension.
inherited
getField(int tagNumber) → dynamic
Returns the value of the field associated with tagNumber, or the default value if it is not set.
inherited
getFieldOrNull(int tagNumber) → dynamic
Returns the value of a field, ignoring any defaults.
inherited
getTagNumber(String fieldName) int?
inherited
hasAd() bool
hasDynamicPricing() bool
hasEndDateDate() bool
hasExpirationAction() bool
hasExpirationDateTime() bool
hasExtension(Extension extension) bool
Returns true if a value of extension is present.
inherited
hasField(int tagNumber) bool
Whether this message has a field associated with tagNumber.
inherited
hasInitialPrice() bool
hasLastPriceReduction() bool
hasPurchasePrice() bool
hasRequiredFields() bool
Whether the message has required fields.
inherited
hasRowVersion() bool
hasStartDateTime() bool
hasTotalClicks() bool
hasTotalViews() bool
isInitialized() bool
Whether all required fields in the message and embedded messages are set.
inherited
mergeFromBuffer(List<int> input, [ExtensionRegistry extensionRegistry = ExtensionRegistry.EMPTY]) → void
Merges serialized protocol buffer data into this message.
inherited
mergeFromCodedBufferReader(CodedBufferReader input, [ExtensionRegistry extensionRegistry = ExtensionRegistry.EMPTY]) → void
Same as mergeFromBuffer, but takes a CodedBufferReader input.
inherited
mergeFromJson(String data, [ExtensionRegistry extensionRegistry = ExtensionRegistry.EMPTY]) → void
Merges field values from data, a JSON object, encoded as described by GeneratedMessage.writeToJson.
inherited
mergeFromJsonMap(Map<String, dynamic> json, [ExtensionRegistry extensionRegistry = ExtensionRegistry.EMPTY]) → void
Merges field values from a JSON object represented as a Dart map.
inherited
mergeFromMessage(GeneratedMessage other) → void
Merges the contents of the other into this message.
inherited
mergeFromProto3Json(Object? json, {TypeRegistry typeRegistry = const TypeRegistry.empty(), bool ignoreUnknownFields = false, bool supportNamesWithUnderscores = true, bool permissiveEnums = false}) → void
Merges field values from json, a JSON object using proto3 encoding.
inherited
mergeUnknownFields(UnknownFieldSet unknownFieldSet) → void
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebuild(void updates(T)) → T

Available on T, provided by the GeneratedMessageGenericExtensions extension

Apply updates to a copy of this message.
setExtension(Extension extension, Object value) → void
Sets the value of a non-repeated extension field to value.
inherited
setField(int tagNumber, Object value) → void
Sets the value of a field by its tagNumber.
inherited
toBuilder() → GeneratedMessage
Creates a writable, shallow copy of this message.
inherited
toDebugString() String
Returns a String representation of this message.
inherited
toProto3Json({TypeRegistry typeRegistry = const TypeRegistry.empty()}) Object?
Returns an Object representing Proto3 JSON serialization of this.
inherited
toString() String
Returns a String representation of this message.
inherited
writeToBuffer() Uint8List
Serialize the message as the protobuf binary format.
inherited
writeToCodedBufferWriter(CodedBufferWriter output) → void
Same as writeToBuffer, but serializes to the given CodedBufferWriter.
inherited
writeToJson() String
Returns a JSON string that encodes this message.
inherited
writeToJsonMap() Map<String, dynamic>
Returns the JSON encoding of this message as a Dart Map.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

create() AdDetails
getDefault() AdDetails