ApplicationGatewayServiceBase class abstract

Annotations
  • @GrpcServiceName.new('ApplicationGatewayService')

Properties

$name String
no setter
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

$addMethod(ServiceMethod method) → void
inherited
$lookupMethod(String name) → ServiceMethod?
inherited
$onMetadata(ServiceCall context) → void
Client metadata handler.
inherited
acceptChallenge(ServiceCall call, AcceptChallengeRequest request) Future<AuthResponse>
acceptChallenge_Pre(ServiceCall $call, Future<AcceptChallengeRequest> $request) Future<AuthResponse>
activeFirstMile(ServiceCall call, AccountId request) Future<BookReturnResponse>
activeFirstMile_Pre(ServiceCall $call, Future<AccountId> $request) Future<BookReturnResponse>
bookReturn(ServiceCall call, BookReturnRequest request) Future<BookReturnResponse>
bookReturn_Pre(ServiceCall $call, Future<BookReturnRequest> $request) Future<BookReturnResponse>
cancel(ServiceCall call, CancelShipmentRequest request) Future<CancelShipmentResponse>
cancel_Pre(ServiceCall $call, Future<CancelShipmentRequest> $request) Future<CancelShipmentResponse>
claimVoucher(ServiceCall call, ClaimVoucherRequest request) Future<ClaimVoucherResponse>
claimVoucher_Pre(ServiceCall $call, Future<ClaimVoucherRequest> $request) Future<ClaimVoucherResponse>
createAd(ServiceCall call, AdDetails request) Future<AdDetails>
createAd_Pre(ServiceCall $call, Future<AdDetails> $request) Future<AdDetails>
createChallenge(ServiceCall call, ChallengeRequest request) Future<ChallengeResonse>
createChallenge_Pre(ServiceCall $call, Future<ChallengeRequest> $request) Future<ChallengeResonse>
createGLSShipment(ServiceCall call, CreateGLSShipmentRequest request) Future<CreateGLSShipmentResponse>
createGLSShipment_Pre(ServiceCall $call, Future<CreateGLSShipmentRequest> $request) Future<CreateGLSShipmentResponse>
defaultGLSRequest(ServiceCall call, AccountId request) Future<CreateGLSShipmentRequest>
defaultGLSRequest_Pre(ServiceCall $call, Future<AccountId> $request) Future<CreateGLSShipmentRequest>
getAccount(ServiceCall call, AccountId request) Future<AccountInfo>
getAccount_Pre(ServiceCall $call, Future<AccountId> $request) Future<AccountInfo>
getAd(ServiceCall call, StoredObjectId request) Future<AdDetails>
getAd_Pre(ServiceCall $call, Future<StoredObjectId> $request) Future<AdDetails>
getCapacity(ServiceCall call, SwipBoxServicePointId request) Future<CapacityResult>
getCapacity_Pre(ServiceCall $call, Future<SwipBoxServicePointId> $request) Future<CapacityResult>
getHomeScreenHeaderInfo(ServiceCall call, HomeScreenHeaderInfoRequest request) Future<HomeScreenHeaderInfoResponse>
getHomeScreenHeaderInfo_Pre(ServiceCall $call, Future<HomeScreenHeaderInfoRequest> $request) Future<HomeScreenHeaderInfoResponse>
getToken(ServiceCall call, TokenRequest request) Future<TokenResponse>
getToken_Pre(ServiceCall $call, Future<TokenRequest> $request) Future<TokenResponse>
listAds(ServiceCall call, AdQuery request) Future<PageResult>
listAds_Pre(ServiceCall $call, Future<AdQuery> $request) Future<PageResult>
listBilling(ServiceCall call, BillingQuery request) Future<PageResult>
listBilling_Pre(ServiceCall $call, Future<BillingQuery> $request) Future<PageResult>
listGLSShipments(ServiceCall call, GLSShipmentQuery request) Future<PageResult>
listGLSShipments_Pre(ServiceCall $call, Future<GLSShipmentQuery> $request) Future<PageResult>
listObjects(ServiceCall call, ObjectQuery request) Future<PageResult>
listObjects_Pre(ServiceCall $call, Future<ObjectQuery> $request) Future<PageResult>
listServicePoints(ServiceCall call, SwipBoxServicePointQuery request) Future<ServicePointList>
listServicePoints_Pre(ServiceCall $call, Future<SwipBoxServicePointQuery> $request) Future<ServicePointList>
listShipments(ServiceCall call, SwipBoxEnduserShipmentQuery request) Future<SwipBoxEnduserShipmentsResult>
listShipments_Pre(ServiceCall $call, Future<SwipBoxEnduserShipmentQuery> $request) Future<SwipBoxEnduserShipmentsResult>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
register(ServiceCall call, DeviceInstallation request) Future<Empty>
register_Pre(ServiceCall $call, Future<DeviceInstallation> $request) Future<Empty>
returnComplete(ServiceCall call, ReturnCompleteRequest request) Future<ReturnCompleteResponse>
returnComplete_Pre(ServiceCall $call, Future<ReturnCompleteRequest> $request) Future<ReturnCompleteResponse>
toString() String
A string representation of this object.
inherited
update(ServiceCall call, Account request) Future<Account>
update_Pre(ServiceCall $call, Future<Account> $request) Future<Account>
updateAd(ServiceCall call, AdDetails request) Future<AdDetails>
updateAd_Pre(ServiceCall $call, Future<AdDetails> $request) Future<AdDetails>
updateUser(ServiceCall call, AccountUser request) Future<AccountUser>
updateUser_Pre(ServiceCall $call, Future<AccountUser> $request) Future<AccountUser>

Operators

operator ==(Object other) bool
The equality operator.
inherited