AsyncServiceBase class abstract

Annotations
  • @GrpcServiceName.new('AsyncService')

Constructors

AsyncServiceBase()

Properties

$name String
no setter
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

$addMethod(ServiceMethod method) → void
inherited
$lookupMethod(String name) → ServiceMethod?
inherited
$onMetadata(ServiceCall context) → void
Client metadata handler.
inherited
completePartition(ServiceCall call, AsyncPartitionResult request) Future<AsyncOperation>
completePartition_Pre(ServiceCall $call, Future<AsyncPartitionResult> $request) Future<AsyncOperation>
get(ServiceCall call, AsyncOperationId request) Future<AsyncOperation>
get_Pre(ServiceCall $call, Future<AsyncOperationId> $request) Future<AsyncOperation>
getResult(ServiceCall call, AsyncOperationId request) Future<AsyncOperationResult>
getResult_Pre(ServiceCall $call, Future<AsyncOperationId> $request) Future<AsyncOperationResult>
launch(ServiceCall call, AsyncOperationLaunch request) Future<AsyncOperation>
launch_Pre(ServiceCall $call, Future<AsyncOperationLaunch> $request) Future<AsyncOperation>
listOperations(ServiceCall call, AsyncOperationQuery request) Future<PageResult>
listOperations_Pre(ServiceCall $call, Future<AsyncOperationQuery> $request) Future<PageResult>
listResults(ServiceCall call, AsyncResultQuery request) Future<PageResult>
listResults_Pre(ServiceCall $call, Future<AsyncResultQuery> $request) Future<PageResult>
listTypes(ServiceCall call, AsyncOperationTypeQuery request) Future<PageResult>
listTypes_Pre(ServiceCall $call, Future<AsyncOperationTypeQuery> $request) Future<PageResult>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
retryAll(ServiceCall call, AsyncOperationId request) Future<AsyncOperation>
retryAll_Pre(ServiceCall $call, Future<AsyncOperationId> $request) Future<AsyncOperation>
retryFailedItems(ServiceCall call, AsyncPartitionId request) Future<AsyncOperation>
retryFailedItems_Pre(ServiceCall $call, Future<AsyncPartitionId> $request) Future<AsyncOperation>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited