AsyncServiceClient class

Annotations
  • @GrpcServiceName.new('AsyncService')

Constructors

AsyncServiceClient(ClientChannel channel, {CallOptions? options, Iterable<ClientInterceptor>? interceptors})

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

$createCall<Q, R>(ClientMethod<Q, R> method, Stream<Q> requests, {CallOptions? options}) → ClientCall<Q, R>
inherited
$createStreamingCall<Q, R>(ClientMethod<Q, R> method, Stream<Q> requests, {CallOptions? options}) → ResponseStream<R>
inherited
$createUnaryCall<Q, R>(ClientMethod<Q, R> method, Q request, {CallOptions? options}) → ResponseFuture<R>
inherited
completePartition(AsyncPartitionResult request, {CallOptions? options}) → ResponseFuture<AsyncOperation>
Async: Complete a pending partition via callback.
get(AsyncOperationId request, {CallOptions? options}) → ResponseFuture<AsyncOperation>
getResult(AsyncOperationId request, {CallOptions? options}) → ResponseFuture<AsyncOperationResult>
launch(AsyncOperationLaunch request, {CallOptions? options}) → ResponseFuture<AsyncOperation>
listOperations(AsyncOperationQuery request, {CallOptions? options}) → ResponseFuture<PageResult>
Async: List Operations AsyncOperationHeader
listResults(AsyncResultQuery request, {CallOptions? options}) → ResponseFuture<PageResult>
Async: List Results for an Operation AsyncPartitionResult
listTypes(AsyncOperationTypeQuery request, {CallOptions? options}) → ResponseFuture<PageResult>
Async: List Operation Types AsyncOperationTypeHeader
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
retryAll(AsyncOperationId request, {CallOptions? options}) → ResponseFuture<AsyncOperation>
Async: Retry all failed items in an operation.
retryFailedItems(AsyncPartitionId request, {CallOptions? options}) → ResponseFuture<AsyncOperation>
Async: Retry all failed items in a partition.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

defaultHost → const String
The hostname for this service.
oauthScopes → const List<String>
OAuth scopes needed for the client.