AuthServiceBase class abstract

Annotations
  • @GrpcServiceName.new('AuthService')

Constructors

AuthServiceBase()

Properties

$name String
no setter
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

$addMethod(ServiceMethod method) → void
inherited
$lookupMethod(String name) → ServiceMethod?
inherited
$onMetadata(ServiceCall context) → void
Client metadata handler.
inherited
acceptChallenge(ServiceCall call, AcceptChallengeRequest request) Future<AuthResponse>
acceptChallenge_Pre(ServiceCall $call, Future<AcceptChallengeRequest> $request) Future<AuthResponse>
authenticate(ServiceCall call, AuthenticationRequest request) Future<AuthenticationResponse>
authenticate_Pre(ServiceCall $call, Future<AuthenticationRequest> $request) Future<AuthenticationResponse>
createChallenge(ServiceCall call, ChallengeRequest request) Future<ChallengeResonse>
createChallenge_Pre(ServiceCall $call, Future<ChallengeRequest> $request) Future<ChallengeResonse>
createLogin(ServiceCall call, CreateLoginRequest request) Future<Login>
createLogin_Pre(ServiceCall $call, Future<CreateLoginRequest> $request) Future<Login>
getCurrentLogin(ServiceCall call, Empty request) Future<Login>
getCurrentLogin_Pre(ServiceCall $call, Future<Empty> $request) Future<Login>
getLogin(ServiceCall call, StringValue request) Future<Login>
getLogin_Pre(ServiceCall $call, Future<StringValue> $request) Future<Login>
listLogins(ServiceCall call, LoginQuery request) Future<PageResult>
listLogins_Pre(ServiceCall $call, Future<LoginQuery> $request) Future<PageResult>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited
updateLogin(ServiceCall call, Login request) Future<Login>
updateLogin_Pre(ServiceCall $call, Future<Login> $request) Future<Login>

Operators

operator ==(Object other) bool
The equality operator.
inherited