BillingServiceBase class abstract

Annotations
  • @GrpcServiceName.new('BillingService')

Constructors

BillingServiceBase()

Properties

$name String
no setter
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

$addMethod(ServiceMethod method) → void
inherited
$lookupMethod(String name) → ServiceMethod?
inherited
$onMetadata(ServiceCall context) → void
Client metadata handler.
inherited
create(ServiceCall call, BillingEvent request) Future<BillingEvent>
create_Pre(ServiceCall $call, Future<BillingEvent> $request) Future<BillingEvent>
export(ServiceCall call, BillingQuery request) Future<ExportResult>
export_Pre(ServiceCall $call, Future<BillingQuery> $request) Future<ExportResult>
getStatus(ServiceCall call, BillingStatusRequest request) Future<BillingStatusResponse>
getStatus_Pre(ServiceCall $call, Future<BillingStatusRequest> $request) Future<BillingStatusResponse>
list(ServiceCall call, BillingQuery request) Future<PageResult>
list_Pre(ServiceCall $call, Future<BillingQuery> $request) Future<PageResult>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited