CollectionServiceBase class abstract

Annotations
  • @GrpcServiceName.new('CollectionService')

Constructors

CollectionServiceBase()

Properties

$name String
no setter
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

$addMethod(ServiceMethod method) → void
inherited
$lookupMethod(String name) → ServiceMethod?
inherited
$onMetadata(ServiceCall context) → void
Client metadata handler.
inherited
addObjects(ServiceCall call, CollectionObjects request) Future<Empty>
addObjects_Pre(ServiceCall $call, Future<CollectionObjects> $request) Future<Empty>
create(ServiceCall call, Collection request) Future<Collection>
create_Pre(ServiceCall $call, Future<Collection> $request) Future<Collection>
delete(ServiceCall call, CollectionId request) Future<Empty>
delete_Pre(ServiceCall $call, Future<CollectionId> $request) Future<Empty>
get(ServiceCall call, CollectionId request) Future<Collection>
get_Pre(ServiceCall $call, Future<CollectionId> $request) Future<Collection>
list(ServiceCall call, CollectionQuery request) Future<PageResult>
list_Pre(ServiceCall $call, Future<CollectionQuery> $request) Future<PageResult>
listObjects(ServiceCall call, CollectionObjectQuery request) Future<PageResult>
listObjects_Pre(ServiceCall $call, Future<CollectionObjectQuery> $request) Future<PageResult>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
removeObjects(ServiceCall call, CollectionObjects request) Future<Empty>
removeObjects_Pre(ServiceCall $call, Future<CollectionObjects> $request) Future<Empty>
toString() String
A string representation of this object.
inherited
update(ServiceCall call, Collection request) Future<Collection>
update_Pre(ServiceCall $call, Future<Collection> $request) Future<Collection>

Operators

operator ==(Object other) bool
The equality operator.
inherited