ConfigurationValueServiceBase class abstract

Annotations
  • @GrpcServiceName.new('ConfigurationValueService')

Properties

$name String
no setter
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

$addMethod(ServiceMethod method) → void
inherited
$lookupMethod(String name) → ServiceMethod?
inherited
$onMetadata(ServiceCall context) → void
Client metadata handler.
inherited
featureFlags_CuratorEnabled(ServiceCall call, BoolValue request) Future<BoolValue>
featureFlags_CuratorEnabled_Pre(ServiceCall $call, Future<BoolValue> $request) Future<BoolValue>
featureFlags_FeedDesignerEnabled(ServiceCall call, BoolValue request) Future<BoolValue>
featureFlags_FeedDesignerEnabled_Pre(ServiceCall $call, Future<BoolValue> $request) Future<BoolValue>
featureFlags_WebsitesEnabled(ServiceCall call, BoolValue request) Future<BoolValue>
featureFlags_WebsitesEnabled_Pre(ServiceCall $call, Future<BoolValue> $request) Future<BoolValue>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
testWebMethod_ManyNotifications(ServiceCall call, Notification request) Future<Notification>
testWebMethod_ManyNotifications_Pre(ServiceCall $call, Future<Notification> $request) Future<Notification>
testWebMethod_ManyValues(ServiceCall call, StringValue request) Future<StringValue>
testWebMethod_ManyValues_Pre(ServiceCall $call, Future<StringValue> $request) Future<StringValue>
testWebMethod_Message(ServiceCall call, StringValue request) Future<StringValue>
testWebMethod_Message_Pre(ServiceCall $call, Future<StringValue> $request) Future<StringValue>
testWebMethod_MyBool(ServiceCall call, BoolValue request) Future<BoolValue>
testWebMethod_MyBool_Pre(ServiceCall $call, Future<BoolValue> $request) Future<BoolValue>
testWebMethod_MyInteger(ServiceCall call, Int32Value request) Future<Int32Value>
testWebMethod_MyInteger_Pre(ServiceCall $call, Future<Int32Value> $request) Future<Int32Value>
testWebMethod_MyLookupValue(ServiceCall call, StringValue request) Future<StringValue>
testWebMethod_MyLookupValue_Pre(ServiceCall $call, Future<StringValue> $request) Future<StringValue>
testWebMethod_Notification(ServiceCall call, Notification request) Future<Notification>
testWebMethod_Notification_Pre(ServiceCall $call, Future<Notification> $request) Future<Notification>
toString() String
A string representation of this object.
inherited
websiteContent_Logo_Pre(ServiceCall $call, Future<UIImage> $request) Future<UIImage>
websiteContent_Menu(ServiceCall call, UIMenu request) Future<UIMenu>
websiteContent_Menu_Pre(ServiceCall $call, Future<UIMenu> $request) Future<UIMenu>
websiteContent_SiteTitle(ServiceCall call, StringValue request) Future<StringValue>
websiteContent_SiteTitle_Pre(ServiceCall $call, Future<StringValue> $request) Future<StringValue>
websiteTemplateSelector_TemplateName(ServiceCall call, StringValue request) Future<StringValue>
websiteTemplateSelector_TemplateName_Pre(ServiceCall $call, Future<StringValue> $request) Future<StringValue>

Operators

operator ==(Object other) bool
The equality operator.
inherited