ConfigurationValueServiceClient class

Annotations
  • @GrpcServiceName.new('ConfigurationValueService')

Constructors

ConfigurationValueServiceClient(ClientChannel channel, {CallOptions? options, Iterable<ClientInterceptor>? interceptors})

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

$createCall<Q, R>(ClientMethod<Q, R> method, Stream<Q> requests, {CallOptions? options}) → ClientCall<Q, R>
inherited
$createStreamingCall<Q, R>(ClientMethod<Q, R> method, Stream<Q> requests, {CallOptions? options}) → ResponseStream<R>
inherited
$createUnaryCall<Q, R>(ClientMethod<Q, R> method, Q request, {CallOptions? options}) → ResponseFuture<R>
inherited
featureFlags_CuratorEnabled(BoolValue request, {CallOptions? options}) → ResponseFuture<BoolValue>
featureFlags_FeedDesignerEnabled(BoolValue request, {CallOptions? options}) → ResponseFuture<BoolValue>
featureFlags_WebsitesEnabled(BoolValue request, {CallOptions? options}) → ResponseFuture<BoolValue>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
testWebMethod_ManyNotifications(Notification request, {CallOptions? options}) → ResponseFuture<Notification>
testWebMethod_ManyValues(StringValue request, {CallOptions? options}) → ResponseFuture<StringValue>
testWebMethod_Message(StringValue request, {CallOptions? options}) → ResponseFuture<StringValue>
testWebMethod_MyBool(BoolValue request, {CallOptions? options}) → ResponseFuture<BoolValue>
testWebMethod_MyInteger(Int32Value request, {CallOptions? options}) → ResponseFuture<Int32Value>
testWebMethod_MyLookupValue(StringValue request, {CallOptions? options}) → ResponseFuture<StringValue>
testWebMethod_Notification(Notification request, {CallOptions? options}) → ResponseFuture<Notification>
toString() String
A string representation of this object.
inherited
websiteContent_Menu(UIMenu request, {CallOptions? options}) → ResponseFuture<UIMenu>
websiteContent_SiteTitle(StringValue request, {CallOptions? options}) → ResponseFuture<StringValue>
websiteTemplateSelector_TemplateName(StringValue request, {CallOptions? options}) → ResponseFuture<StringValue>

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

defaultHost → const String
The hostname for this service.
oauthScopes → const List<String>
OAuth scopes needed for the client.