ContainerServiceClient class

Container Service

Annotations
  • @GrpcServiceName.new('ContainerService')

Constructors

ContainerServiceClient(ClientChannel channel, {CallOptions? options, Iterable<ClientInterceptor>? interceptors})

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

$createCall<Q, R>(ClientMethod<Q, R> method, Stream<Q> requests, {CallOptions? options}) → ClientCall<Q, R>
inherited
$createStreamingCall<Q, R>(ClientMethod<Q, R> method, Stream<Q> requests, {CallOptions? options}) → ResponseStream<R>
inherited
$createUnaryCall<Q, R>(ClientMethod<Q, R> method, Q request, {CallOptions? options}) → ResponseFuture<R>
inherited
addObjects(ContainerOperation request, {CallOptions? options}) → ResponseFuture<Empty>
create(Container request, {CallOptions? options}) → ResponseFuture<Container>
Containers: Create Container
createLabels(CreateContainerLabelsRequest request, {CallOptions? options}) → ResponseFuture<CreateContainerLabelsResponse>
Containers: Create Labels
delete(ContainerId request, {CallOptions? options}) → ResponseFuture<Empty>
Containers: Delete Container
findFromObject(StoredObjectId request, {CallOptions? options}) → ResponseFuture<Container>
Containers: Find From Object Id
get(ContainerId request, {CallOptions? options}) → ResponseFuture<ContainerInfo>
Containers: Get Container
getOwner(ContainerId request, {CallOptions? options}) → ResponseFuture<AccountPublicProfile>
Containers: Get Owner
importContainerOrder(ImportContainerOrderRequest request, {CallOptions? options}) → ResponseFuture<AsyncOperation>
list(ContainerQuery request, {CallOptions? options}) → ResponseFuture<PageResult>
Containers: List Containers Container
listObjects(ContainerObjectQuery request, {CallOptions? options}) → ResponseFuture<PageResult>
Containers: List Objects StoredObject
move(MoveContainerOperation request, {CallOptions? options}) → ResponseFuture<Empty>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
removeObjects(ContainerOperation request, {CallOptions? options}) → ResponseFuture<Empty>
reset(ContainerId request, {CallOptions? options}) → ResponseFuture<Container>
toString() String
A string representation of this object.
inherited
update(Container request, {CallOptions? options}) → ResponseFuture<Container>
Containers: Update Container

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

defaultHost → const String
The hostname for this service.
oauthScopes → const List<String>
OAuth scopes needed for the client.