Delivery class

Available extensions

Constructors

Delivery({RowVersion? rowVersion, DeliveryId? id, Timestamp? deliveryTime, Delivery_DeliveryStatus? status, StringValue? responsibleUserId, BoolValue? isExtraDelivery, StringValue? reference, OrderId? orderId, Timestamp? createdTime, Timestamp? lastStatusChange, TransportDetails? transportDetails, TrackAndTraceInfo? trackAndTraceInfo, StringValue? comments})
factory
Delivery.fromBuffer(List<int> data, [ExtensionRegistry registry = $pb.ExtensionRegistry.EMPTY])
factory
Delivery.fromJson(String json, [ExtensionRegistry registry = $pb.ExtensionRegistry.EMPTY])
factory

Properties

comments ↔ StringValue
getter/setter pair
createdTime ↔ Timestamp
getter/setter pair
deliveryTime ↔ Timestamp
getter/setter pair
hashCode int
Calculates a hash code based on the contents of the protobuf.
no setterinherited
id DeliveryId
getter/setter pair
info_ → BuilderInfo
no setter
isExtraDelivery ↔ BoolValue
getter/setter pair
isFrozen bool
Returns true if this message is marked read-only. Otherwise false.
no setterinherited
lastStatusChange ↔ Timestamp
getter/setter pair
orderId OrderId
getter/setter pair
reference ↔ StringValue
getter/setter pair
responsibleUserId ↔ StringValue
getter/setter pair
rowVersion RowVersion
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
status Delivery_DeliveryStatus
getter/setter pair
trackAndTraceInfo TrackAndTraceInfo
getter/setter pair
transportDetails TransportDetails
getter/setter pair
unknownFields → UnknownFieldSet
no setterinherited

Methods

addExtension(Extension extension, Object? value) → void
Adds an extension field value to a repeated field.
inherited
check() → void
Throws a StateError if the message has required fields without a value.
inherited
clear() → void
Clears all data that was set in this message.
inherited
clearComments() → void
clearCreatedTime() → void
clearDeliveryTime() → void
clearExtension(Extension extension) → void
Clears an extension field and also removes the extension.
inherited
clearField(int tagNumber) → void
Clears the contents of a given field.
inherited
clearId() → void
clearIsExtraDelivery() → void
clearLastStatusChange() → void
clearOrderId() → void
clearReference() → void
clearResponsibleUserId() → void
clearRowVersion() → void
clearStatus() → void
clearTrackAndTraceInfo() → void
clearTransportDetails() → void
clone() Delivery
Creates a deep copy of the fields in this message.
copyWith(void updates(Delivery)) Delivery
Apply updates to a copy of this message.
createEmptyInstance() Delivery
Creates an empty instance of the same message type as this.
deepCopy() → T

Available on T, provided by the GeneratedMessageGenericExtensions extension

Returns a writable deep copy of this message.
ensureComments() → StringValue
ensureCreatedTime() → Timestamp
ensureDeliveryTime() → Timestamp
ensureId() DeliveryId
ensureIsExtraDelivery() → BoolValue
ensureLastStatusChange() → Timestamp
ensureOrderId() OrderId
ensureReference() → StringValue
ensureResponsibleUserId() → StringValue
ensureRowVersion() RowVersion
ensureTrackAndTraceInfo() TrackAndTraceInfo
ensureTransportDetails() TransportDetails
extensionsAreInitialized() bool
inherited
freeze() → GeneratedMessage
Make this message read-only.
inherited
getDefaultForField(int tagNumber) → dynamic
Returns the default value for the given field.
inherited
getExtension(Extension extension) → dynamic
Returns the value of extension.
inherited
getField(int tagNumber) → dynamic
Returns the value of the field associated with tagNumber, or the default value if it is not set.
inherited
getFieldOrNull(int tagNumber) → dynamic
Returns the value of a field, ignoring any defaults.
inherited
getTagNumber(String fieldName) int?
inherited
hasComments() bool
hasCreatedTime() bool
hasDeliveryTime() bool
hasExtension(Extension extension) bool
Returns true if a value of extension is present.
inherited
hasField(int tagNumber) bool
Whether this message has a field associated with tagNumber.
inherited
hasId() bool
hasIsExtraDelivery() bool
hasLastStatusChange() bool
hasOrderId() bool
hasReference() bool
hasRequiredFields() bool
Whether the message has required fields.
inherited
hasResponsibleUserId() bool
hasRowVersion() bool
hasStatus() bool
hasTrackAndTraceInfo() bool
hasTransportDetails() bool
isInitialized() bool
Whether all required fields in the message and embedded messages are set.
inherited
mergeFromBuffer(List<int> input, [ExtensionRegistry extensionRegistry = ExtensionRegistry.EMPTY]) → void
Merges serialized protocol buffer data into this message.
inherited
mergeFromCodedBufferReader(CodedBufferReader input, [ExtensionRegistry extensionRegistry = ExtensionRegistry.EMPTY]) → void
Same as mergeFromBuffer, but takes a CodedBufferReader input.
inherited
mergeFromJson(String data, [ExtensionRegistry extensionRegistry = ExtensionRegistry.EMPTY]) → void
Merges field values from data, a JSON object, encoded as described by GeneratedMessage.writeToJson.
inherited
mergeFromJsonMap(Map<String, dynamic> json, [ExtensionRegistry extensionRegistry = ExtensionRegistry.EMPTY]) → void
Merges field values from a JSON object represented as a Dart map.
inherited
mergeFromMessage(GeneratedMessage other) → void
Merges the contents of the other into this message.
inherited
mergeFromProto3Json(Object? json, {TypeRegistry typeRegistry = const TypeRegistry.empty(), bool ignoreUnknownFields = false, bool supportNamesWithUnderscores = true, bool permissiveEnums = false}) → void
Merges field values from json, a JSON object using proto3 encoding.
inherited
mergeUnknownFields(UnknownFieldSet unknownFieldSet) → void
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebuild(void updates(T)) → T

Available on T, provided by the GeneratedMessageGenericExtensions extension

Apply updates to a copy of this message.
setExtension(Extension extension, Object value) → void
Sets the value of a non-repeated extension field to value.
inherited
setField(int tagNumber, Object value) → void
Sets the value of a field by its tagNumber.
inherited
toBuilder() → GeneratedMessage
Creates a writable, shallow copy of this message.
inherited
toDebugString() String
Returns a String representation of this message.
inherited
toProto3Json({TypeRegistry typeRegistry = const TypeRegistry.empty()}) Object?
Returns an Object representing Proto3 JSON serialization of this.
inherited
toString() String
Returns a String representation of this message.
inherited
writeToBuffer() Uint8List
Serialize the message as the protobuf binary format.
inherited
writeToCodedBufferWriter(CodedBufferWriter output) → void
Same as writeToBuffer, but serializes to the given CodedBufferWriter.
inherited
writeToJson() String
Returns a JSON string that encodes this message.
inherited
writeToJsonMap() Map<String, dynamic>
Returns the JSON encoding of this message as a Dart Map.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

create() Delivery
getDefault() Delivery