DeliveryServiceBase class abstract

Annotations
  • @GrpcServiceName.new('DeliveryService')

Constructors

DeliveryServiceBase()

Properties

$name String
no setter
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

$addMethod(ServiceMethod method) → void
inherited
$lookupMethod(String name) → ServiceMethod?
inherited
$onMetadata(ServiceCall context) → void
Client metadata handler.
inherited
addDocument(ServiceCall call, DeliveryDocument request) Future<DeliveryDocument>
addDocument_Pre(ServiceCall $call, Future<DeliveryDocument> $request) Future<DeliveryDocument>
addObject(ServiceCall call, DeliveryObject request) Future<DeliveryObject>
addObject_Pre(ServiceCall $call, Future<DeliveryObject> $request) Future<DeliveryObject>
create(ServiceCall call, Delivery request) Future<Delivery>
create_Pre(ServiceCall $call, Future<Delivery> $request) Future<Delivery>
createBatch(ServiceCall call, DeliveryBatch request) Future<DeliveryBatch>
createBatch_Pre(ServiceCall $call, Future<DeliveryBatch> $request) Future<DeliveryBatch>
delete(ServiceCall call, DeliveryId request) Future<Empty>
delete_Pre(ServiceCall $call, Future<DeliveryId> $request) Future<Empty>
deleteObject(ServiceCall call, DeliveryObject request) Future<Empty>
deleteObject_Pre(ServiceCall $call, Future<DeliveryObject> $request) Future<Empty>
get(ServiceCall call, DeliveryId request) Future<DeliveryInfo>
get_Pre(ServiceCall $call, Future<DeliveryId> $request) Future<DeliveryInfo>
getBatch(ServiceCall call, DeliveryBatchId request) Future<DeliveryBatchDetails>
getBatch_Pre(ServiceCall $call, Future<DeliveryBatchId> $request) Future<DeliveryBatchDetails>
getBatchPackingList(ServiceCall call, DeliveryBatchId request) Future<DeliveryPackingList>
getBatchPackingList_Pre(ServiceCall $call, Future<DeliveryBatchId> $request) Future<DeliveryPackingList>
getDeliveryLabel(ServiceCall call, DeliveryId request) Future<DeliveryLabelResult>
getDeliveryLabel_Pre(ServiceCall $call, Future<DeliveryId> $request) Future<DeliveryLabelResult>
getDocument(ServiceCall call, DeliveryDocumentId request) Future<DeliveryDocument>
getDocument_Pre(ServiceCall $call, Future<DeliveryDocumentId> $request) Future<DeliveryDocument>
getPackingList(ServiceCall call, DeliveryId request) Future<DeliveryPackingList>
getPackingList_Pre(ServiceCall $call, Future<DeliveryId> $request) Future<DeliveryPackingList>
getStatus(ServiceCall call, DeliveryStatusRequest request) Future<DeliveryStatusResponse>
getStatus_Pre(ServiceCall $call, Future<DeliveryStatusRequest> $request) Future<DeliveryStatusResponse>
getTransportMethod(ServiceCall call, SKU request) Future<TransportMethod>
getTransportMethod_Pre(ServiceCall $call, Future<SKU> $request) Future<TransportMethod>
list(ServiceCall call, DeliveryQuery request) Future<PageResult>
list_Pre(ServiceCall $call, Future<DeliveryQuery> $request) Future<PageResult>
listBatches(ServiceCall call, DeliveryBatchQuery request) Future<PageResult>
listBatches_Pre(ServiceCall $call, Future<DeliveryBatchQuery> $request) Future<PageResult>
listObjects(ServiceCall call, DeliveryObjectQuery request) Future<PageResult>
listObjects_Pre(ServiceCall $call, Future<DeliveryObjectQuery> $request) Future<PageResult>
listTransportFeatures(ServiceCall call, TransportFeatureQuery request) Future<PageResult>
listTransportFeatures_Pre(ServiceCall $call, Future<TransportFeatureQuery> $request) Future<PageResult>
listTransportMethods(ServiceCall call, TransportMethodQuery request) Future<PageResult>
listTransportMethods_Pre(ServiceCall $call, Future<TransportMethodQuery> $request) Future<PageResult>
nextFreeDeliveryTime(ServiceCall call, DeliveryTimeQuery request) Future<Timestamp>
nextFreeDeliveryTime_Pre(ServiceCall $call, Future<DeliveryTimeQuery> $request) Future<Timestamp>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
printAndShip(ServiceCall call, PrintRequest request) Future<PrintResult>
printAndShip_Pre(ServiceCall $call, Future<PrintRequest> $request) Future<PrintResult>
readyForTransit(ServiceCall call, ReadyForTransitRequest request) Future<Delivery>
readyForTransit_Pre(ServiceCall $call, Future<ReadyForTransitRequest> $request) Future<Delivery>
toString() String
A string representation of this object.
inherited
update(ServiceCall call, Delivery request) Future<Delivery>
update_Pre(ServiceCall $call, Future<Delivery> $request) Future<Delivery>
updateBatch(ServiceCall call, DeliveryBatch request) Future<DeliveryBatchDetails>
updateBatch_Pre(ServiceCall $call, Future<DeliveryBatch> $request) Future<DeliveryBatchDetails>
updateObject(ServiceCall call, DeliveryObject request) Future<DeliveryObject>
updateObject_Pre(ServiceCall $call, Future<DeliveryObject> $request) Future<DeliveryObject>
updatePackingList(ServiceCall call, DeliveryPackingList request) Future<DeliveryPackingList>
updatePackingList_Pre(ServiceCall $call, Future<DeliveryPackingList> $request) Future<DeliveryPackingList>
updateWeight(ServiceCall call, UpdateDeliveryWeight request) Future<DeliveryInfo>
updateWeight_Pre(ServiceCall $call, Future<UpdateDeliveryWeight> $request) Future<DeliveryInfo>

Operators

operator ==(Object other) bool
The equality operator.
inherited