DeliveryServiceClient class

Delivery Service

Annotations
  • @GrpcServiceName.new('DeliveryService')

Constructors

DeliveryServiceClient(ClientChannel channel, {CallOptions? options, Iterable<ClientInterceptor>? interceptors})

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

$createCall<Q, R>(ClientMethod<Q, R> method, Stream<Q> requests, {CallOptions? options}) → ClientCall<Q, R>
inherited
$createStreamingCall<Q, R>(ClientMethod<Q, R> method, Stream<Q> requests, {CallOptions? options}) → ResponseStream<R>
inherited
$createUnaryCall<Q, R>(ClientMethod<Q, R> method, Q request, {CallOptions? options}) → ResponseFuture<R>
inherited
addDocument(DeliveryDocument request, {CallOptions? options}) → ResponseFuture<DeliveryDocument>
addObject(DeliveryObject request, {CallOptions? options}) → ResponseFuture<DeliveryObject>
create(Delivery request, {CallOptions? options}) → ResponseFuture<Delivery>
Deliveries: Create Delivery
createBatch(DeliveryBatch request, {CallOptions? options}) → ResponseFuture<DeliveryBatch>
delete(DeliveryId request, {CallOptions? options}) → ResponseFuture<Empty>
Deliveries: Delete Delivery
deleteObject(DeliveryObject request, {CallOptions? options}) → ResponseFuture<Empty>
get(DeliveryId request, {CallOptions? options}) → ResponseFuture<DeliveryInfo>
Deliveries: Get Delivery
getBatch(DeliveryBatchId request, {CallOptions? options}) → ResponseFuture<DeliveryBatchDetails>
getBatchPackingList(DeliveryBatchId request, {CallOptions? options}) → ResponseFuture<DeliveryPackingList>
getDeliveryLabel(DeliveryId request, {CallOptions? options}) → ResponseFuture<DeliveryLabelResult>
getDocument(DeliveryDocumentId request, {CallOptions? options}) → ResponseFuture<DeliveryDocument>
getPackingList(DeliveryId request, {CallOptions? options}) → ResponseFuture<DeliveryPackingList>
getStatus(DeliveryStatusRequest request, {CallOptions? options}) → ResponseFuture<DeliveryStatusResponse>
Deliveries: Get Status
getTransportMethod(SKU request, {CallOptions? options}) → ResponseFuture<TransportMethod>
list(DeliveryQuery request, {CallOptions? options}) → ResponseFuture<PageResult>
Deliveries: List Deliveries DeliveryHeader
listBatches(DeliveryBatchQuery request, {CallOptions? options}) → ResponseFuture<PageResult>
Deliveries: List Batches DeliveryBatchHeader
listObjects(DeliveryObjectQuery request, {CallOptions? options}) → ResponseFuture<PageResult>
Deliveries: List Objects DeliveryObject
listTransportFeatures(TransportFeatureQuery request, {CallOptions? options}) → ResponseFuture<PageResult>
Deliveries: List Transport Features TransportFeature
listTransportMethods(TransportMethodQuery request, {CallOptions? options}) → ResponseFuture<PageResult>
Deliveries: List Transport Methods TransportMethod
nextFreeDeliveryTime(DeliveryTimeQuery request, {CallOptions? options}) → ResponseFuture<Timestamp>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
printAndShip(PrintRequest request, {CallOptions? options}) → ResponseFuture<PrintResult>
readyForTransit(ReadyForTransitRequest request, {CallOptions? options}) → ResponseFuture<Delivery>
toString() String
A string representation of this object.
inherited
update(Delivery request, {CallOptions? options}) → ResponseFuture<Delivery>
Deliveries: Update Delivery
updateBatch(DeliveryBatch request, {CallOptions? options}) → ResponseFuture<DeliveryBatchDetails>
updateObject(DeliveryObject request, {CallOptions? options}) → ResponseFuture<DeliveryObject>
updatePackingList(DeliveryPackingList request, {CallOptions? options}) → ResponseFuture<DeliveryPackingList>
updateWeight(UpdateDeliveryWeight request, {CallOptions? options}) → ResponseFuture<DeliveryInfo>

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

defaultHost → const String
The hostname for this service.
oauthScopes → const List<String>
OAuth scopes needed for the client.