ErrorServiceBase class abstract

Annotations
  • @GrpcServiceName.new('ErrorService')

Constructors

ErrorServiceBase()

Properties

$name String
no setter
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

$addMethod(ServiceMethod method) → void
inherited
$lookupMethod(String name) → ServiceMethod?
inherited
$onMetadata(ServiceCall context) → void
Client metadata handler.
inherited
delete(ServiceCall call, ErrorId request) Future<Empty>
delete_Pre(ServiceCall $call, Future<ErrorId> $request) Future<Empty>
get(ServiceCall call, ErrorId request) Future<Error>
get_Pre(ServiceCall $call, Future<ErrorId> $request) Future<Error>
list(ServiceCall call, ErrorQuery request) Future<PageResult>
list_Pre(ServiceCall $call, Future<ErrorQuery> $request) Future<PageResult>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
retry(ServiceCall call, Event request) Future<UUID>
retry_Pre(ServiceCall $call, Future<Event> $request) Future<UUID>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited