EventServiceBase class abstract

Annotations
  • @GrpcServiceName.new('EventService')

Constructors

EventServiceBase()

Properties

$name String
no setter
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

$addMethod(ServiceMethod method) → void
inherited
$lookupMethod(String name) → ServiceMethod?
inherited
$onMetadata(ServiceCall context) → void
Client metadata handler.
inherited
dispatch(ServiceCall call, Event request) Future<Event>
dispatch_Pre(ServiceCall $call, Future<Event> $request) Future<Event>
list(ServiceCall call, EventQuery request) Future<PageResult>
list_Pre(ServiceCall $call, Future<EventQuery> $request) Future<PageResult>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited