FeedServiceBase class abstract

Annotations
  • @GrpcServiceName.new('FeedService')

Constructors

FeedServiceBase()

Properties

$name String
no setter
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

$addMethod(ServiceMethod method) → void
inherited
$lookupMethod(String name) → ServiceMethod?
inherited
$onMetadata(ServiceCall context) → void
Client metadata handler.
inherited
delete(ServiceCall call, FeedItemId request) Future<Empty>
delete_Pre(ServiceCall $call, Future<FeedItemId> $request) Future<Empty>
getStatus(ServiceCall call, FeedStatusRequest request) Future<FeedStatusResponse>
getStatus_Pre(ServiceCall $call, Future<FeedStatusRequest> $request) Future<FeedStatusResponse>
getUrlMapping(ServiceCall call, UrlMappingRequest request) Future<UrlMappingResponse>
getUrlMapping_Pre(ServiceCall $call, Future<UrlMappingRequest> $request) Future<UrlMappingResponse>
list(ServiceCall call, FeedQuery request) Future<PageResult>
list_Pre(ServiceCall $call, Future<FeedQuery> $request) Future<PageResult>
listStatic(ServiceCall call, FeedQuery request) Future<PageResult>
listStatic_Pre(ServiceCall $call, Future<FeedQuery> $request) Future<PageResult>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited
upsert(ServiceCall call, FeedItem request) Future<FeedItem>
upsert_Pre(ServiceCall $call, Future<FeedItem> $request) Future<FeedItem>

Operators

operator ==(Object other) bool
The equality operator.
inherited