InvitationServiceBase class abstract

Annotations
  • @GrpcServiceName.new('InvitationService')

Constructors

InvitationServiceBase()

Properties

$name String
no setter
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

$addMethod(ServiceMethod method) → void
inherited
$lookupMethod(String name) → ServiceMethod?
inherited
$onMetadata(ServiceCall context) → void
Client metadata handler.
inherited
create(ServiceCall call, InvitationCreateRequest request) Future<InvitationStatus>
create_Pre(ServiceCall $call, Future<InvitationCreateRequest> $request) Future<InvitationStatus>
list(ServiceCall call, InvitationQuery request) Future<PageResult>
list_Pre(ServiceCall $call, Future<InvitationQuery> $request) Future<PageResult>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
redeem(ServiceCall call, InvitationRedemption request) Future<InvitationRedemptionResult>
redeem_Pre(ServiceCall $call, Future<InvitationRedemption> $request) Future<InvitationRedemptionResult>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited