StoredObjectMetadata class

Available extensions

Constructors

StoredObjectMetadata({StringValue? rowVersion, StringValue? objectId, StringValue? title, StringValue? description, Iterable<StoredImage>? images, Iterable<Tag>? tags, AudioAttachment? audioDescription, DoubleValue? weightInGrams, Iterable<Tag>? englishGoogleTags, Iterable<Tag>? localGoogleTags, StringValue? brand, StringValue? color, StringValue? condition, StringValue? size, Barcode? barcode, StringValue? conditionDescription, Int32Value? conditionPct, StringValue? group})
factory
StoredObjectMetadata.fromBuffer(List<int> data, [ExtensionRegistry registry = $pb.ExtensionRegistry.EMPTY])
factory
StoredObjectMetadata.fromJson(String json, [ExtensionRegistry registry = $pb.ExtensionRegistry.EMPTY])
factory

Properties

audioDescription AudioAttachment
getter/setter pair
barcode Barcode
getter/setter pair
brand ↔ StringValue
getter/setter pair
color ↔ StringValue
getter/setter pair
condition ↔ StringValue
getter/setter pair
conditionDescription ↔ StringValue
getter/setter pair
conditionPct ↔ Int32Value
getter/setter pair
description ↔ StringValue
getter/setter pair
englishGoogleTags → PbList<Tag>
no setter
group ↔ StringValue
getter/setter pair
hashCode int
Calculates a hash code based on the contents of the protobuf.
no setterinherited
images → PbList<StoredImage>
no setter
info_ → BuilderInfo
no setter
isFrozen bool
Returns true if this message is marked read-only. Otherwise false.
no setterinherited
localGoogleTags → PbList<Tag>
no setter
objectId ↔ StringValue
getter/setter pair
rowVersion ↔ StringValue
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
size ↔ StringValue
getter/setter pair
tags → PbList<Tag>
no setter
title ↔ StringValue
getter/setter pair
unknownFields → UnknownFieldSet
no setterinherited
weightInGrams ↔ DoubleValue
getter/setter pair

Methods

addExtension(Extension extension, Object? value) → void
Adds an extension field value to a repeated field.
inherited
check() → void
Throws a StateError if the message has required fields without a value.
inherited
clear() → void
Clears all data that was set in this message.
inherited
clearAudioDescription() → void
clearBarcode() → void
clearBrand() → void
clearColor() → void
clearCondition() → void
clearConditionDescription() → void
clearConditionPct() → void
clearDescription() → void
clearExtension(Extension extension) → void
Clears an extension field and also removes the extension.
inherited
clearField(int tagNumber) → void
Clears the contents of a given field.
inherited
clearGroup() → void
clearObjectId() → void
clearRowVersion() → void
clearSize() → void
clearTitle() → void
clearWeightInGrams() → void
clone() StoredObjectMetadata
Creates a deep copy of the fields in this message.
copyWith(void updates(StoredObjectMetadata)) StoredObjectMetadata
Apply updates to a copy of this message.
createEmptyInstance() StoredObjectMetadata
Creates an empty instance of the same message type as this.
deepCopy() → T

Available on T, provided by the GeneratedMessageGenericExtensions extension

Returns a writable deep copy of this message.
ensureAudioDescription() AudioAttachment
ensureBarcode() Barcode
ensureBrand() → StringValue
ensureColor() → StringValue
ensureCondition() → StringValue
ensureConditionDescription() → StringValue
ensureConditionPct() → Int32Value
ensureDescription() → StringValue
ensureGroup() → StringValue
ensureObjectId() → StringValue
ensureRowVersion() → StringValue
ensureSize() → StringValue
ensureTitle() → StringValue
ensureWeightInGrams() → DoubleValue
extensionsAreInitialized() bool
inherited
freeze() → GeneratedMessage
Make this message read-only.
inherited
getDefaultForField(int tagNumber) → dynamic
Returns the default value for the given field.
inherited
getExtension(Extension extension) → dynamic
Returns the value of extension.
inherited
getField(int tagNumber) → dynamic
Returns the value of the field associated with tagNumber, or the default value if it is not set.
inherited
getFieldOrNull(int tagNumber) → dynamic
Returns the value of a field, ignoring any defaults.
inherited
getTagNumber(String fieldName) int?
inherited
hasAudioDescription() bool
hasBarcode() bool
hasBrand() bool
hasColor() bool
hasCondition() bool
hasConditionDescription() bool
hasConditionPct() bool
hasDescription() bool
hasExtension(Extension extension) bool
Returns true if a value of extension is present.
inherited
hasField(int tagNumber) bool
Whether this message has a field associated with tagNumber.
inherited
hasGroup() bool
hasObjectId() bool
hasRequiredFields() bool
Whether the message has required fields.
inherited
hasRowVersion() bool
hasSize() bool
hasTitle() bool
hasWeightInGrams() bool
isInitialized() bool
Whether all required fields in the message and embedded messages are set.
inherited
mergeFromBuffer(List<int> input, [ExtensionRegistry extensionRegistry = ExtensionRegistry.EMPTY]) → void
Merges serialized protocol buffer data into this message.
inherited
mergeFromCodedBufferReader(CodedBufferReader input, [ExtensionRegistry extensionRegistry = ExtensionRegistry.EMPTY]) → void
Same as mergeFromBuffer, but takes a CodedBufferReader input.
inherited
mergeFromJson(String data, [ExtensionRegistry extensionRegistry = ExtensionRegistry.EMPTY]) → void
Merges field values from data, a JSON object, encoded as described by GeneratedMessage.writeToJson.
inherited
mergeFromJsonMap(Map<String, dynamic> json, [ExtensionRegistry extensionRegistry = ExtensionRegistry.EMPTY]) → void
Merges field values from a JSON object represented as a Dart map.
inherited
mergeFromMessage(GeneratedMessage other) → void
Merges the contents of the other into this message.
inherited
mergeFromProto3Json(Object? json, {TypeRegistry typeRegistry = const TypeRegistry.empty(), bool ignoreUnknownFields = false, bool supportNamesWithUnderscores = true, bool permissiveEnums = false}) → void
Merges field values from json, a JSON object using proto3 encoding.
inherited
mergeUnknownFields(UnknownFieldSet unknownFieldSet) → void
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebuild(void updates(T)) → T

Available on T, provided by the GeneratedMessageGenericExtensions extension

Apply updates to a copy of this message.
setExtension(Extension extension, Object value) → void
Sets the value of a non-repeated extension field to value.
inherited
setField(int tagNumber, Object value) → void
Sets the value of a field by its tagNumber.
inherited
toBuilder() → GeneratedMessage
Creates a writable, shallow copy of this message.
inherited
toDebugString() String
Returns a String representation of this message.
inherited
toProto3Json({TypeRegistry typeRegistry = const TypeRegistry.empty()}) Object?
Returns an Object representing Proto3 JSON serialization of this.
inherited
toString() String
Returns a String representation of this message.
inherited
writeToBuffer() Uint8List
Serialize the message as the protobuf binary format.
inherited
writeToCodedBufferWriter(CodedBufferWriter output) → void
Same as writeToBuffer, but serializes to the given CodedBufferWriter.
inherited
writeToJson() String
Returns a JSON string that encodes this message.
inherited
writeToJsonMap() Map<String, dynamic>
Returns the JSON encoding of this message as a Dart Map.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited