AdFieldMap_AdField class
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- name → String
-
This enum's name, as specified in the .proto file.
finalinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- value → int
-
This enum's integer value, as specified in the .proto file.
finalinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
Returns this enum's
nameor thevalueif names are not represented.inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
valueOf(
int value) → AdFieldMap_AdField?
Constants
- Barcode → const AdFieldMap_AdField
- Brand → const AdFieldMap_AdField
- Color → const AdFieldMap_AdField
- ConditionDescription → const AdFieldMap_AdField
- ConditionPct → const AdFieldMap_AdField
- CurrentPrice → const AdFieldMap_AdField
- Description → const AdFieldMap_AdField
- DescriptionIfEmpty → const AdFieldMap_AdField
- Embeddings → const AdFieldMap_AdField
- Group → const AdFieldMap_AdField
- Images → const AdFieldMap_AdField
- None → const AdFieldMap_AdField
- Size → const AdFieldMap_AdField
- State → const AdFieldMap_AdField
- SuggestedPrice → const AdFieldMap_AdField
- Tags → const AdFieldMap_AdField
- Timestamp → const AdFieldMap_AdField
- Title → const AdFieldMap_AdField
-
values
→ const List<
AdFieldMap_AdField> - WeightInGrams → const AdFieldMap_AdField