MetadataServiceClient class

Metadata Service

Annotations
  • @GrpcServiceName.new('MetadataService')

Constructors

MetadataServiceClient(ClientChannel channel, {CallOptions? options, Iterable<ClientInterceptor>? interceptors})

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

$createCall<Q, R>(ClientMethod<Q, R> method, Stream<Q> requests, {CallOptions? options}) → ClientCall<Q, R>
inherited
$createStreamingCall<Q, R>(ClientMethod<Q, R> method, Stream<Q> requests, {CallOptions? options}) → ResponseStream<R>
inherited
$createUnaryCall<Q, R>(ClientMethod<Q, R> method, Q request, {CallOptions? options}) → ResponseFuture<R>
inherited
decide(Barcode request, {CallOptions? options}) → ResponseFuture<StockDecision>
feedback(StockDecisionFeedback request, {CallOptions? options}) → ResponseFuture<StockDecision>
get(StoredObjectId request, {CallOptions? options}) → ResponseFuture<MetadataDetails>
getFromUrl(URL request, {CallOptions? options}) → ResponseFuture<MetadataDetails>
inferMetadata(MetadataInferenceContext request, {CallOptions? options}) → ResponseFuture<MetadataInferenceContext>
list(MetadataQuery request, {CallOptions? options}) → ResponseFuture<PageResult>
Metadata: List metadata Metadata
listFields(MetadataFieldQuery request, {CallOptions? options}) → ResponseFuture<PageResult>
Metadata: List Metadata Fields MetadataField
listProviders(MetadataProviderQuery request, {CallOptions? options}) → ResponseFuture<PageResult>
Metadata: List Metadata Providers MetadataProviderHeader
lookup(Barcode request, {CallOptions? options}) → ResponseFuture<BarcodeMetadata>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited
upsert(BarcodeMetadata request, {CallOptions? options}) → ResponseFuture<BarcodeMetadata>

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

defaultHost → const String
The hostname for this service.
oauthScopes → const List<String>
OAuth scopes needed for the client.