NotificationServiceBase class abstract

Annotations
  • @GrpcServiceName.new('NotificationService')

Constructors

NotificationServiceBase()

Properties

$name String
no setter
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

$addMethod(ServiceMethod method) → void
inherited
$lookupMethod(String name) → ServiceMethod?
inherited
$onMetadata(ServiceCall context) → void
Client metadata handler.
inherited
create(ServiceCall call, Notification request) Future<NotificationId>
create_Pre(ServiceCall $call, Future<Notification> $request) Future<NotificationId>
createDefault(ServiceCall call, CreateDefaultNotificationRequest request) Future<NotificationId>
createDefault_Pre(ServiceCall $call, Future<CreateDefaultNotificationRequest> $request) Future<NotificationId>
list(ServiceCall call, NotificationQuery request) Future<PageResult>
list_Pre(ServiceCall $call, Future<NotificationQuery> $request) Future<PageResult>
listSettings(ServiceCall call, NotificationSettingQuery request) Future<PageResult>
listSettings_Pre(ServiceCall $call, Future<NotificationSettingQuery> $request) Future<PageResult>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited
upsertSetting(ServiceCall call, NotificationSetting request) Future<NotificationSetting>
upsertSetting_Pre(ServiceCall $call, Future<NotificationSetting> $request) Future<NotificationSetting>

Operators

operator ==(Object other) bool
The equality operator.
inherited