OrderServiceClient class

Order Service

Annotations
  • @GrpcServiceName.new('OrderService')

Constructors

OrderServiceClient(ClientChannel channel, {CallOptions? options, Iterable<ClientInterceptor>? interceptors})

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

$createCall<Q, R>(ClientMethod<Q, R> method, Stream<Q> requests, {CallOptions? options}) → ClientCall<Q, R>
inherited
$createStreamingCall<Q, R>(ClientMethod<Q, R> method, Stream<Q> requests, {CallOptions? options}) → ResponseStream<R>
inherited
$createUnaryCall<Q, R>(ClientMethod<Q, R> method, Q request, {CallOptions? options}) → ResponseFuture<R>
inherited
book(OrderId request, {CallOptions? options}) → ResponseFuture<OrderStatus>
cancel(OrderId request, {CallOptions? options}) → ResponseFuture<OrderStatus>
create(DraftOrder request, {CallOptions? options}) → ResponseFuture<Order>
Orders: Create
createPayment(CreatePaymentRequest request, {CallOptions? options}) → ResponseFuture<CreatePaymentResult>
get(OrderId request, {CallOptions? options}) → ResponseFuture<OrderDetails>
Orders: Get Order
getDraft(DraftOrderId request, {CallOptions? options}) → ResponseFuture<DraftOrder>
getInvoice(InvoiceRequest request, {CallOptions? options}) → ResponseFuture<InvoiceResponse>
list(OrderQuery request, {CallOptions? options}) → ResponseFuture<PageResult>
Orders: List Orders Order
listHeaders(OrderQuery request, {CallOptions? options}) → ResponseFuture<PageResult>
Orders: List Headers OrderHeader
listStatus(OrderStatusQuery request, {CallOptions? options}) → ResponseFuture<PageResult>
Orders: List Status OrderStatus
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited
upsertDraft(DraftOrder request, {CallOptions? options}) → ResponseFuture<DraftOrder>
verifyDraft(DraftOrder request, {CallOptions? options}) → ResponseFuture<DraftOrder>

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

defaultHost → const String
The hostname for this service.
oauthScopes → const List<String>
OAuth scopes needed for the client.