PayoutServiceBase class abstract

Annotations
  • @GrpcServiceName.new('PayoutService')

Constructors

PayoutServiceBase()

Properties

$name String
no setter
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

$addMethod(ServiceMethod method) → void
inherited
$lookupMethod(String name) → ServiceMethod?
inherited
$onMetadata(ServiceCall context) → void
Client metadata handler.
inherited
create(ServiceCall call, PayoutRequest request) Future<PayoutStatus>
create_Pre(ServiceCall $call, Future<PayoutRequest> $request) Future<PayoutStatus>
export(ServiceCall call, PayoutExportRequest request) Future<PayoutExportResponse>
export_Pre(ServiceCall $call, Future<PayoutExportRequest> $request) Future<PayoutExportResponse>
get(ServiceCall call, PayoutId request) Future<PayoutStatus>
get_Pre(ServiceCall $call, Future<PayoutId> $request) Future<PayoutStatus>
getBalance(ServiceCall call, PayoutBalanceRequest request) Future<PayoutBalance>
getBalance_Pre(ServiceCall $call, Future<PayoutBalanceRequest> $request) Future<PayoutBalance>
importBankStatement(ServiceCall call, PayoutImportBankStatementRequest request) Future<AsyncOperation>
importBankStatement_Pre(ServiceCall $call, Future<PayoutImportBankStatementRequest> $request) Future<AsyncOperation>
list(ServiceCall call, PayoutQuery request) Future<PageResult>
list_Pre(ServiceCall $call, Future<PayoutQuery> $request) Future<PageResult>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited
update(ServiceCall call, PayoutStatus request) Future<PayoutStatus>
update_Pre(ServiceCall $call, Future<PayoutStatus> $request) Future<PayoutStatus>

Operators

operator ==(Object other) bool
The equality operator.
inherited