PayoutServiceClient class

Payout Service

Annotations
  • @GrpcServiceName.new('PayoutService')

Constructors

PayoutServiceClient(ClientChannel channel, {CallOptions? options, Iterable<ClientInterceptor>? interceptors})

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

$createCall<Q, R>(ClientMethod<Q, R> method, Stream<Q> requests, {CallOptions? options}) → ClientCall<Q, R>
inherited
$createStreamingCall<Q, R>(ClientMethod<Q, R> method, Stream<Q> requests, {CallOptions? options}) → ResponseStream<R>
inherited
$createUnaryCall<Q, R>(ClientMethod<Q, R> method, Q request, {CallOptions? options}) → ResponseFuture<R>
inherited
create(PayoutRequest request, {CallOptions? options}) → ResponseFuture<PayoutStatus>
Payouts: Create Payout
export(PayoutExportRequest request, {CallOptions? options}) → ResponseFuture<PayoutExportResponse>
get(PayoutId request, {CallOptions? options}) → ResponseFuture<PayoutStatus>
Payouts: Get Payout
getBalance(PayoutBalanceRequest request, {CallOptions? options}) → ResponseFuture<PayoutBalance>
Payouts: Get Balance
importBankStatement(PayoutImportBankStatementRequest request, {CallOptions? options}) → ResponseFuture<AsyncOperation>
list(PayoutQuery request, {CallOptions? options}) → ResponseFuture<PageResult>
Payouts: List Payouts PayoutStatus
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited
update(PayoutStatus request, {CallOptions? options}) → ResponseFuture<PayoutStatus>
Payouts: Update Payout

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

defaultHost → const String
The hostname for this service.
oauthScopes → const List<String>
OAuth scopes needed for the client.