PromotionServiceBase class abstract

Annotations
  • @GrpcServiceName.new('PromotionService')

Constructors

PromotionServiceBase()

Properties

$name String
no setter
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

$addMethod(ServiceMethod method) → void
inherited
$lookupMethod(String name) → ServiceMethod?
inherited
$onMetadata(ServiceCall context) → void
Client metadata handler.
inherited
create(ServiceCall call, Promotion request) Future<Promotion>
create_Pre(ServiceCall $call, Future<Promotion> $request) Future<Promotion>
get(ServiceCall call, PromotionId request) Future<Promotion>
get_Pre(ServiceCall $call, Future<PromotionId> $request) Future<Promotion>
list(ServiceCall call, PromotionQuery request) Future<PageResult>
list_Pre(ServiceCall $call, Future<PromotionQuery> $request) Future<PageResult>
listRules(ServiceCall call, PromotionRuleQuery request) Future<PageResult>
listRules_Pre(ServiceCall $call, Future<PromotionRuleQuery> $request) Future<PageResult>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited
update(ServiceCall call, Promotion request) Future<Promotion>
update_Pre(ServiceCall $call, Future<Promotion> $request) Future<Promotion>

Operators

operator ==(Object other) bool
The equality operator.
inherited