PublicServiceClient class
- Annotations
-
- @GrpcServiceName.new('PublicService')
Properties
-
hashCode
→ int
-
The hash code for this object.
no setterinherited
-
runtimeType
→ Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
$createCall<Q, R>(ClientMethod<Q, R> method, Stream<Q> requests, {CallOptions? options})
→ ClientCall<Q, R>
-
inherited
-
$createStreamingCall<Q, R>(ClientMethod<Q, R> method, Stream<Q> requests, {CallOptions? options})
→ ResponseStream<R>
-
inherited
-
$createUnaryCall<Q, R>(ClientMethod<Q, R> method, Q request, {CallOptions? options})
→ ResponseFuture<R>
-
inherited
-
getPublicProfile(AccountId request, {CallOptions? options})
→ ResponseFuture<AccountPublicProfile>
-
-
listFeedItems(FeedQuery request, {CallOptions? options})
→ ResponseFuture<PageResult>
-
Public: List Feed Items FeedItem
-
noSuchMethod(Invocation invocation)
→ dynamic
-
Invoked when a nonexistent method or property is accessed.
inherited
-
search(SearchQuery request, {CallOptions? options})
→ ResponseFuture<PageResult>
-
Public: Search SearchObject
-
toString()
→ String
-
A string representation of this object.
inherited