ReviewServiceBase class abstract

Annotations
  • @GrpcServiceName.new('ReviewService')

Constructors

ReviewServiceBase()

Properties

$name String
no setter
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

$addMethod(ServiceMethod method) → void
inherited
$lookupMethod(String name) → ServiceMethod?
inherited
$onMetadata(ServiceCall context) → void
Client metadata handler.
inherited
create(ServiceCall call, ObjectReview request) Future<ObjectReview>
create_Pre(ServiceCall $call, Future<ObjectReview> $request) Future<ObjectReview>
getAccountSummary(ServiceCall call, AccountId request) Future<ReviewSummary>
getAccountSummary_Pre(ServiceCall $call, Future<AccountId> $request) Future<ReviewSummary>
getObjectSummary(ServiceCall call, StoredObjectId request) Future<ReviewSummary>
getObjectSummary_Pre(ServiceCall $call, Future<StoredObjectId> $request) Future<ReviewSummary>
list(ServiceCall call, ReviewQuery request) Future<ReviewResult>
list_Pre(ServiceCall $call, Future<ReviewQuery> $request) Future<ReviewResult>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited