SalesChannelServiceBase class abstract

Annotations
  • @GrpcServiceName.new('SalesChannelService')

Constructors

SalesChannelServiceBase()

Properties

$name String
no setter
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

$addMethod(ServiceMethod method) → void
inherited
$lookupMethod(String name) → ServiceMethod?
inherited
$onMetadata(ServiceCall context) → void
Client metadata handler.
inherited
cancelReIndex(ServiceCall call, BackgroundProcessId request) Future<ReIndexStatus>
cancelReIndex_Pre(ServiceCall $call, Future<BackgroundProcessId> $request) Future<ReIndexStatus>
getReIndexStatus(ServiceCall call, BackgroundProcessId request) Future<ReIndexStatus>
getReIndexStatus_Pre(ServiceCall $call, Future<BackgroundProcessId> $request) Future<ReIndexStatus>
listReIndexBatchStatus(ServiceCall call, ReIndexBatchQuery request) Future<PageResult>
listReIndexBatchStatus_Pre(ServiceCall $call, Future<ReIndexBatchQuery> $request) Future<PageResult>
listReIndexStatus(ServiceCall call, ReIndexQuery request) Future<PageResult>
listReIndexStatus_Pre(ServiceCall $call, Future<ReIndexQuery> $request) Future<PageResult>
listSalesChannels(ServiceCall call, SalesChannelsQuery request) Future<PageResult>
listSalesChannels_Pre(ServiceCall $call, Future<SalesChannelsQuery> $request) Future<PageResult>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
startReIndex(ServiceCall call, ReIndexRequest request) Future<ReIndexResponse>
startReIndex_Pre(ServiceCall $call, Future<ReIndexRequest> $request) Future<ReIndexResponse>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited