SalesChannelServiceClient class
- Annotations
-
- @GrpcServiceName.new('SalesChannelService')
Properties
-
hashCode
→ int
-
The hash code for this object.
no setterinherited
-
runtimeType
→ Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
$createCall<Q, R>(ClientMethod<Q, R> method, Stream<Q> requests, {CallOptions? options})
→ ClientCall<Q, R>
-
inherited
-
$createStreamingCall<Q, R>(ClientMethod<Q, R> method, Stream<Q> requests, {CallOptions? options})
→ ResponseStream<R>
-
inherited
-
$createUnaryCall<Q, R>(ClientMethod<Q, R> method, Q request, {CallOptions? options})
→ ResponseFuture<R>
-
inherited
-
cancelReIndex(BackgroundProcessId request, {CallOptions? options})
→ ResponseFuture<ReIndexStatus>
-
-
getReIndexStatus(BackgroundProcessId request, {CallOptions? options})
→ ResponseFuture<ReIndexStatus>
-
-
listReIndexBatchStatus(ReIndexBatchQuery request, {CallOptions? options})
→ ResponseFuture<PageResult>
-
Sales Channels: List ReIndex Batch Status ReIndexBatchStatus
-
listReIndexStatus(ReIndexQuery request, {CallOptions? options})
→ ResponseFuture<PageResult>
-
Sales Channels: List ReIndex Status ReIndexStatus
-
listSalesChannels(SalesChannelsQuery request, {CallOptions? options})
→ ResponseFuture<PageResult>
-
Sales Channels: List Sales Channels SalesChannelHeader
-
noSuchMethod(Invocation invocation)
→ dynamic
-
Invoked when a nonexistent method or property is accessed.
inherited
-
startReIndex(ReIndexRequest request, {CallOptions? options})
→ ResponseFuture<ReIndexResponse>
-
-
toString()
→ String
-
A string representation of this object.
inherited