ScannerGatewayServiceClient class

Annotations
  • @GrpcServiceName.new('ScannerGatewayService')

Constructors

ScannerGatewayServiceClient(ClientChannel channel, {CallOptions? options, Iterable<ClientInterceptor>? interceptors})

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

$createCall<Q, R>(ClientMethod<Q, R> method, Stream<Q> requests, {CallOptions? options}) → ClientCall<Q, R>
inherited
$createStreamingCall<Q, R>(ClientMethod<Q, R> method, Stream<Q> requests, {CallOptions? options}) → ResponseStream<R>
inherited
$createUnaryCall<Q, R>(ClientMethod<Q, R> method, Q request, {CallOptions? options}) → ResponseFuture<R>
inherited
get(ScannerId request, {CallOptions? options}) → ResponseFuture<ScannerDetails>
getAccountPublicProfile(UUID request, {CallOptions? options}) → ResponseFuture<AccountPublicProfile>
getOwner(ContainerId request, {CallOptions? options}) → ResponseFuture<AccountPublicProfile>
getOwnerFromBarcode(Barcode request, {CallOptions? options}) → ResponseFuture<AccountPublicProfile>
list(ScannerQuery request, {CallOptions? options}) → ResponseFuture<PageResult>
Scanners: List Scanners ScannerHeader
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited
upsert(Scanner request, {CallOptions? options}) → ResponseFuture<Scanner>

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

defaultHost → const String
The hostname for this service.
oauthScopes → const List<String>
OAuth scopes needed for the client.