getTemplate method
Proxying other services, to avoid calling backend directly from scanner client Avoids auth problems and double implementation of connection logic Also it makes sense that the scanner client is only the client of the scanner backend They are two pieces of the same pie and have ultra low latency Ultimately we might even hide the whole scanner behind a router and deny external traffic from the client.
Implementation
$grpc.ResponseFuture<$7.Template> getTemplate(
$2.TemplateId request, {
$grpc.CallOptions? options,
}) {
return $createUnaryCall(_$getTemplate, request, options: options);
}