SearchObject class

Available extensions

Constructors

SearchObject({StoredObjectId? target, Iterable<StoredImage>? images, Iterable<Tag>? tags, Credit? price, SearchObject_ObjectSource? source, bool? active, StringValue? title, StringValue? brand, StringValue? size, StringValue? description, SKU? sKU, StringValue? condition, Barcode? barcode, StringValue? conditionDescription, Int32Value? conditionPct, Timestamp? updatedTime, bool? featured, Timestamp? lastPriceDrop, Link? shareURL, StringValue? color, StringValue? storeId, AccountId? accountId, StringValue? trackingId, Timestamp? createdTime, Credit? previousPrice, SearchObjectBadge? badge, StringValue? group})
factory
SearchObject.fromBuffer(List<int> data, [ExtensionRegistry registry = $pb.ExtensionRegistry.EMPTY])
factory
SearchObject.fromJson(String json, [ExtensionRegistry registry = $pb.ExtensionRegistry.EMPTY])
factory

Properties

accountId AccountId
getter/setter pair
active bool
getter/setter pair
badge SearchObjectBadge
getter/setter pair
barcode Barcode
getter/setter pair
brand ↔ StringValue
getter/setter pair
color ↔ StringValue
getter/setter pair
condition ↔ StringValue
getter/setter pair
conditionDescription ↔ StringValue
getter/setter pair
conditionPct ↔ Int32Value
getter/setter pair
createdTime ↔ Timestamp
getter/setter pair
description ↔ StringValue
getter/setter pair
getter/setter pair
group ↔ StringValue
getter/setter pair
hashCode int
Calculates a hash code based on the contents of the protobuf.
no setterinherited
images → PbList<StoredImage>
no setter
info_ → BuilderInfo
no setter
isFrozen bool
Returns true if this message is marked read-only. Otherwise false.
no setterinherited
lastPriceDrop ↔ Timestamp
getter/setter pair
previousPrice Credit
getter/setter pair
price Credit
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
shareURL Link
getter/setter pair
size ↔ StringValue
getter/setter pair
sKU SKU
getter/setter pair
source SearchObject_ObjectSource
getter/setter pair
storeId ↔ StringValue
getter/setter pair
tags → PbList<Tag>
no setter
target StoredObjectId
getter/setter pair
title ↔ StringValue
getter/setter pair
trackingId ↔ StringValue
getter/setter pair
unknownFields → UnknownFieldSet
no setterinherited
updatedTime ↔ Timestamp
getter/setter pair

Methods

addExtension(Extension extension, Object? value) → void
Adds an extension field value to a repeated field.
inherited
check() → void
Throws a StateError if the message has required fields without a value.
inherited
clear() → void
Clears all data that was set in this message.
inherited
clearAccountId() → void
clearActive() → void
clearBadge() → void
clearBarcode() → void
clearBrand() → void
clearColor() → void
clearCondition() → void
clearConditionDescription() → void
clearConditionPct() → void
clearCreatedTime() → void
clearDescription() → void
clearExtension(Extension extension) → void
Clears an extension field and also removes the extension.
inherited
clearFeatured() → void
clearField(int tagNumber) → void
Clears the contents of a given field.
inherited
clearGroup() → void
clearLastPriceDrop() → void
clearPreviousPrice() → void
clearPrice() → void
clearShareURL() → void
clearSize() → void
clearSKU() → void
clearSource() → void
clearStoreId() → void
clearTarget() → void
clearTitle() → void
clearTrackingId() → void
clearUpdatedTime() → void
clone() SearchObject
Creates a deep copy of the fields in this message.
copyWith(void updates(SearchObject)) SearchObject
Apply updates to a copy of this message.
createEmptyInstance() SearchObject
Creates an empty instance of the same message type as this.
deepCopy() → T

Available on T, provided by the GeneratedMessageGenericExtensions extension

Returns a writable deep copy of this message.
ensureAccountId() AccountId
ensureBadge() SearchObjectBadge
ensureBarcode() Barcode
ensureBrand() → StringValue
ensureColor() → StringValue
ensureCondition() → StringValue
ensureConditionDescription() → StringValue
ensureConditionPct() → Int32Value
ensureCreatedTime() → Timestamp
ensureDescription() → StringValue
ensureGroup() → StringValue
ensureLastPriceDrop() → Timestamp
ensurePreviousPrice() Credit
ensurePrice() Credit
ensureShareURL() Link
ensureSize() → StringValue
ensureSKU() SKU
ensureStoreId() → StringValue
ensureTarget() StoredObjectId
ensureTitle() → StringValue
ensureTrackingId() → StringValue
ensureUpdatedTime() → Timestamp
extensionsAreInitialized() bool
inherited
freeze() → GeneratedMessage
Make this message read-only.
inherited
getDefaultForField(int tagNumber) → dynamic
Returns the default value for the given field.
inherited
getExtension(Extension extension) → dynamic
Returns the value of extension.
inherited
getField(int tagNumber) → dynamic
Returns the value of the field associated with tagNumber, or the default value if it is not set.
inherited
getFieldOrNull(int tagNumber) → dynamic
Returns the value of a field, ignoring any defaults.
inherited
getTagNumber(String fieldName) int?
inherited
hasAccountId() bool
hasActive() bool
hasBadge() bool
hasBarcode() bool
hasBrand() bool
hasColor() bool
hasCondition() bool
hasConditionDescription() bool
hasConditionPct() bool
hasCreatedTime() bool
hasDescription() bool
hasExtension(Extension extension) bool
Returns true if a value of extension is present.
inherited
hasFeatured() bool
hasField(int tagNumber) bool
Whether this message has a field associated with tagNumber.
inherited
hasGroup() bool
hasLastPriceDrop() bool
hasPreviousPrice() bool
hasPrice() bool
hasRequiredFields() bool
Whether the message has required fields.
inherited
hasShareURL() bool
hasSize() bool
hasSKU() bool
hasSource() bool
hasStoreId() bool
hasTarget() bool
hasTitle() bool
hasTrackingId() bool
hasUpdatedTime() bool
isInitialized() bool
Whether all required fields in the message and embedded messages are set.
inherited
mergeFromBuffer(List<int> input, [ExtensionRegistry extensionRegistry = ExtensionRegistry.EMPTY]) → void
Merges serialized protocol buffer data into this message.
inherited
mergeFromCodedBufferReader(CodedBufferReader input, [ExtensionRegistry extensionRegistry = ExtensionRegistry.EMPTY]) → void
Same as mergeFromBuffer, but takes a CodedBufferReader input.
inherited
mergeFromJson(String data, [ExtensionRegistry extensionRegistry = ExtensionRegistry.EMPTY]) → void
Merges field values from data, a JSON object, encoded as described by GeneratedMessage.writeToJson.
inherited
mergeFromJsonMap(Map<String, dynamic> json, [ExtensionRegistry extensionRegistry = ExtensionRegistry.EMPTY]) → void
Merges field values from a JSON object represented as a Dart map.
inherited
mergeFromMessage(GeneratedMessage other) → void
Merges the contents of the other into this message.
inherited
mergeFromProto3Json(Object? json, {TypeRegistry typeRegistry = const TypeRegistry.empty(), bool ignoreUnknownFields = false, bool supportNamesWithUnderscores = true, bool permissiveEnums = false}) → void
Merges field values from json, a JSON object using proto3 encoding.
inherited
mergeUnknownFields(UnknownFieldSet unknownFieldSet) → void
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebuild(void updates(T)) → T

Available on T, provided by the GeneratedMessageGenericExtensions extension

Apply updates to a copy of this message.
setExtension(Extension extension, Object value) → void
Sets the value of a non-repeated extension field to value.
inherited
setField(int tagNumber, Object value) → void
Sets the value of a field by its tagNumber.
inherited
toBuilder() → GeneratedMessage
Creates a writable, shallow copy of this message.
inherited
toDebugString() String
Returns a String representation of this message.
inherited
toProto3Json({TypeRegistry typeRegistry = const TypeRegistry.empty()}) Object?
Returns an Object representing Proto3 JSON serialization of this.
inherited
toString() String
Returns a String representation of this message.
inherited
writeToBuffer() Uint8List
Serialize the message as the protobuf binary format.
inherited
writeToCodedBufferWriter(CodedBufferWriter output) → void
Same as writeToBuffer, but serializes to the given CodedBufferWriter.
inherited
writeToJson() String
Returns a JSON string that encodes this message.
inherited
writeToJsonMap() Map<String, dynamic>
Returns the JSON encoding of this message as a Dart Map.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

create() SearchObject
getDefault() SearchObject