SearchQuery class

Available extensions

Constructors

SearchQuery({ContinuationToken? continuation, StringValue? query, Iterable<Tag>? tags, AccountId? sourceAccountId, Credit? priceFrom, Credit? priceTo, Iterable<String>? orderBy, Iterable<String>? facets, AccountId? excludeAccountId, Barcode? barcode, Int32Value? conditionAbove, bool? saveAsLatest, bool? featured, StringValue? shareUrl, StringValue? hiddenQuery, StringValue? storeId, Iterable<SearchObjectBadge_BadgeType>? withBadge, StringValue? relatedUrl, Vector? relatedVector, Vector? collectionVector, StringValue? group})
factory
SearchQuery.fromBuffer(List<int> data, [ExtensionRegistry registry = $pb.ExtensionRegistry.EMPTY])
factory
SearchQuery.fromJson(String json, [ExtensionRegistry registry = $pb.ExtensionRegistry.EMPTY])
factory

Properties

barcode Barcode
getter/setter pair
collectionVector Vector
getter/setter pair
conditionAbove ↔ Int32Value
getter/setter pair
continuation ContinuationToken
getter/setter pair
excludeAccountId AccountId
getter/setter pair
facets → PbList<String>
no setter
getter/setter pair
group ↔ StringValue
getter/setter pair
hashCode int
Calculates a hash code based on the contents of the protobuf.
no setterinherited
hiddenQuery ↔ StringValue
getter/setter pair
info_ → BuilderInfo
no setter
isFrozen bool
Returns true if this message is marked read-only. Otherwise false.
no setterinherited
orderBy → PbList<String>
no setter
priceFrom Credit
getter/setter pair
priceTo Credit
getter/setter pair
query ↔ StringValue
getter/setter pair
relatedUrl ↔ StringValue
getter/setter pair
relatedVector Vector
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
saveAsLatest bool
getter/setter pair
shareUrl ↔ StringValue
getter/setter pair
sourceAccountId AccountId
getter/setter pair
storeId ↔ StringValue
getter/setter pair
tags → PbList<Tag>
no setter
unknownFields → UnknownFieldSet
no setterinherited
withBadge → PbList<SearchObjectBadge_BadgeType>
no setter

Methods

addExtension(Extension extension, Object? value) → void
Adds an extension field value to a repeated field.
inherited
check() → void
Throws a StateError if the message has required fields without a value.
inherited
clear() → void
Clears all data that was set in this message.
inherited
clearBarcode() → void
clearCollectionVector() → void
clearConditionAbove() → void
clearContinuation() → void
clearExcludeAccountId() → void
clearExtension(Extension extension) → void
Clears an extension field and also removes the extension.
inherited
clearFeatured() → void
clearField(int tagNumber) → void
Clears the contents of a given field.
inherited
clearGroup() → void
clearHiddenQuery() → void
clearPriceFrom() → void
clearPriceTo() → void
clearQuery() → void
clearRelatedUrl() → void
clearRelatedVector() → void
clearSaveAsLatest() → void
clearShareUrl() → void
clearSourceAccountId() → void
clearStoreId() → void
clone() SearchQuery
Creates a deep copy of the fields in this message.
copyWith(void updates(SearchQuery)) SearchQuery
Apply updates to a copy of this message.
createEmptyInstance() SearchQuery
Creates an empty instance of the same message type as this.
deepCopy() → T

Available on T, provided by the GeneratedMessageGenericExtensions extension

Returns a writable deep copy of this message.
ensureBarcode() Barcode
ensureCollectionVector() Vector
ensureConditionAbove() → Int32Value
ensureContinuation() ContinuationToken
ensureExcludeAccountId() AccountId
ensureGroup() → StringValue
ensureHiddenQuery() → StringValue
ensurePriceFrom() Credit
ensurePriceTo() Credit
ensureQuery() → StringValue
ensureRelatedUrl() → StringValue
ensureRelatedVector() Vector
ensureShareUrl() → StringValue
ensureSourceAccountId() AccountId
ensureStoreId() → StringValue
extensionsAreInitialized() bool
inherited
freeze() → GeneratedMessage
Make this message read-only.
inherited
getDefaultForField(int tagNumber) → dynamic
Returns the default value for the given field.
inherited
getExtension(Extension extension) → dynamic
Returns the value of extension.
inherited
getField(int tagNumber) → dynamic
Returns the value of the field associated with tagNumber, or the default value if it is not set.
inherited
getFieldOrNull(int tagNumber) → dynamic
Returns the value of a field, ignoring any defaults.
inherited
getTagNumber(String fieldName) int?
inherited
hasBarcode() bool
hasCollectionVector() bool
hasConditionAbove() bool
hasContinuation() bool
hasExcludeAccountId() bool
hasExtension(Extension extension) bool
Returns true if a value of extension is present.
inherited
hasFeatured() bool
hasField(int tagNumber) bool
Whether this message has a field associated with tagNumber.
inherited
hasGroup() bool
hasHiddenQuery() bool
hasPriceFrom() bool
hasPriceTo() bool
hasQuery() bool
hasRelatedUrl() bool
hasRelatedVector() bool
hasRequiredFields() bool
Whether the message has required fields.
inherited
hasSaveAsLatest() bool
hasShareUrl() bool
hasSourceAccountId() bool
hasStoreId() bool
isInitialized() bool
Whether all required fields in the message and embedded messages are set.
inherited
mergeFromBuffer(List<int> input, [ExtensionRegistry extensionRegistry = ExtensionRegistry.EMPTY]) → void
Merges serialized protocol buffer data into this message.
inherited
mergeFromCodedBufferReader(CodedBufferReader input, [ExtensionRegistry extensionRegistry = ExtensionRegistry.EMPTY]) → void
Same as mergeFromBuffer, but takes a CodedBufferReader input.
inherited
mergeFromJson(String data, [ExtensionRegistry extensionRegistry = ExtensionRegistry.EMPTY]) → void
Merges field values from data, a JSON object, encoded as described by GeneratedMessage.writeToJson.
inherited
mergeFromJsonMap(Map<String, dynamic> json, [ExtensionRegistry extensionRegistry = ExtensionRegistry.EMPTY]) → void
Merges field values from a JSON object represented as a Dart map.
inherited
mergeFromMessage(GeneratedMessage other) → void
Merges the contents of the other into this message.
inherited
mergeFromProto3Json(Object? json, {TypeRegistry typeRegistry = const TypeRegistry.empty(), bool ignoreUnknownFields = false, bool supportNamesWithUnderscores = true, bool permissiveEnums = false}) → void
Merges field values from json, a JSON object using proto3 encoding.
inherited
mergeUnknownFields(UnknownFieldSet unknownFieldSet) → void
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebuild(void updates(T)) → T

Available on T, provided by the GeneratedMessageGenericExtensions extension

Apply updates to a copy of this message.
setExtension(Extension extension, Object value) → void
Sets the value of a non-repeated extension field to value.
inherited
setField(int tagNumber, Object value) → void
Sets the value of a field by its tagNumber.
inherited
toBuilder() → GeneratedMessage
Creates a writable, shallow copy of this message.
inherited
toDebugString() String
Returns a String representation of this message.
inherited
toProto3Json({TypeRegistry typeRegistry = const TypeRegistry.empty()}) Object?
Returns an Object representing Proto3 JSON serialization of this.
inherited
toString() String
Returns a String representation of this message.
inherited
writeToBuffer() Uint8List
Serialize the message as the protobuf binary format.
inherited
writeToCodedBufferWriter(CodedBufferWriter output) → void
Same as writeToBuffer, but serializes to the given CodedBufferWriter.
inherited
writeToJson() String
Returns a JSON string that encodes this message.
inherited
writeToJsonMap() Map<String, dynamic>
Returns the JSON encoding of this message as a Dart Map.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

create() SearchQuery
getDefault() SearchQuery