SearchServiceClient class

Annotations
  • @GrpcServiceName.new('SearchService')

Constructors

SearchServiceClient(ClientChannel channel, {CallOptions? options, Iterable<ClientInterceptor>? interceptors})

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

$createCall<Q, R>(ClientMethod<Q, R> method, Stream<Q> requests, {CallOptions? options}) → ClientCall<Q, R>
inherited
$createStreamingCall<Q, R>(ClientMethod<Q, R> method, Stream<Q> requests, {CallOptions? options}) → ResponseStream<R>
inherited
$createUnaryCall<Q, R>(ClientMethod<Q, R> method, Q request, {CallOptions? options}) → ResponseFuture<R>
inherited
deleteSavedSearch(SavedSearchId request, {CallOptions? options}) → ResponseFuture<SavedSearchId>
deleteSearchAgent(SearchAgentId request, {CallOptions? options}) → ResponseFuture<Empty>
getSearchAgent(SearchAgentId request, {CallOptions? options}) → ResponseFuture<SearchAgent>
listSavedSearches(SavedSearchQuery request, {CallOptions? options}) → ResponseFuture<PageResult>
Search: List Saved Searches SavedSearch
listSearchAgents(SearchAgentQuery request, {CallOptions? options}) → ResponseFuture<PageResult>
Search: List Search Agents SearchAgentHeader
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
Search: Search SearchObject
searchBySKU(SKU request, {CallOptions? options}) → ResponseFuture<SearchObject>
searchWithFacets(SearchQuery request, {CallOptions? options}) → ResponseFuture<SearchResult>
suggestTags(SearchQuery request, {CallOptions? options}) → ResponseFuture<TagList>
toString() String
A string representation of this object.
inherited
upsertSavedSearch(SavedSearch request, {CallOptions? options}) → ResponseFuture<SavedSearch>
upsertSearchAgent(SearchAgent request, {CallOptions? options}) → ResponseFuture<SearchAgent>

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

defaultHost → const String
The hostname for this service.
oauthScopes → const List<String>
OAuth scopes needed for the client.