ServicePointServiceBase class abstract

Annotations
  • @GrpcServiceName.new('ServicePointService')

Constructors

ServicePointServiceBase()

Properties

$name String
no setter
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

$addMethod(ServiceMethod method) → void
inherited
$lookupMethod(String name) → ServiceMethod?
inherited
$onMetadata(ServiceCall context) → void
Client metadata handler.
inherited
get(ServiceCall call, ServicePointId request) Future<ServicePoint>
get_Pre(ServiceCall $call, Future<ServicePointId> $request) Future<ServicePoint>
getState(ServiceCall call, ServicePointId request) Future<ServicePointState>
getState_Pre(ServiceCall $call, Future<ServicePointId> $request) Future<ServicePointState>
list(ServiceCall call, ServicePointQuery request) Future<PageResult>
list_Pre(ServiceCall $call, Future<ServicePointQuery> $request) Future<PageResult>
listStored(ServiceCall call, ServicePointQuery request) Future<PageResult>
listStored_Pre(ServiceCall $call, Future<ServicePointQuery> $request) Future<PageResult>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited
updateState(ServiceCall call, ServicePointState request) Future<ServicePointState>
updateState_Pre(ServiceCall $call, Future<ServicePointState> $request) Future<ServicePointState>

Operators

operator ==(Object other) bool
The equality operator.
inherited