StatisticsServiceClient class

Statistics Service

Annotations
  • @GrpcServiceName.new('StatisticsService')

Constructors

StatisticsServiceClient(ClientChannel channel, {CallOptions? options, Iterable<ClientInterceptor>? interceptors})

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

$createCall<Q, R>(ClientMethod<Q, R> method, Stream<Q> requests, {CallOptions? options}) → ClientCall<Q, R>
inherited
$createStreamingCall<Q, R>(ClientMethod<Q, R> method, Stream<Q> requests, {CallOptions? options}) → ResponseStream<R>
inherited
$createUnaryCall<Q, R>(ClientMethod<Q, R> method, Q request, {CallOptions? options}) → ResponseFuture<R>
inherited
deleteChart(ChartId request, {CallOptions? options}) → ResponseFuture<Empty>
getChart(ChartId request, {CallOptions? options}) → ResponseFuture<Chart>
list(StatisticsQuery request, {CallOptions? options}) → ResponseFuture<PageResult>
Stats: List Stats StatisticResult
listCharts(ChartQuery request, {CallOptions? options}) → ResponseFuture<PageResult>
Stats: List Charts ChartHeader
listDescriptors(StatisticDescriptorQuery request, {CallOptions? options}) → ResponseFuture<PageResult>
Stats: List Descriptors StatisticDescriptor
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited
upsertChart(Chart request, {CallOptions? options}) → ResponseFuture<Chart>

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

defaultHost → const String
The hostname for this service.
oauthScopes → const List<String>
OAuth scopes needed for the client.