StoredImage class

Available extensions

Constructors

StoredImage({RowVersion? rowVersion, String? name, Int32Value? rotationDeg, Int32Value? order, Int32Value? cropTopX, Int32Value? cropTopY, Int32Value? cropBottomX, Int32Value? cropBottomY, StringValue? imageDataBase64, Iterable<ImageAnnotation>? annotations, Int32Value? fullWidth, Int32Value? fullHeight, BoolValue? isAsset, AccountId? accountId})
factory
StoredImage.fromBuffer(List<int> data, [ExtensionRegistry registry = $pb.ExtensionRegistry.EMPTY])
factory
StoredImage.fromJson(String json, [ExtensionRegistry registry = $pb.ExtensionRegistry.EMPTY])
factory

Properties

accountId AccountId
getter/setter pair
annotations → PbList<ImageAnnotation>
no setter
cropBottomX ↔ Int32Value
getter/setter pair
cropBottomY ↔ Int32Value
getter/setter pair
cropTopX ↔ Int32Value
getter/setter pair
cropTopY ↔ Int32Value
getter/setter pair
fullHeight ↔ Int32Value
getter/setter pair
fullWidth ↔ Int32Value
getter/setter pair
hashCode int
Calculates a hash code based on the contents of the protobuf.
no setterinherited
imageDataBase64 ↔ StringValue
getter/setter pair
info_ → BuilderInfo
no setter
isAsset ↔ BoolValue
getter/setter pair
isFrozen bool
Returns true if this message is marked read-only. Otherwise false.
no setterinherited
name String
getter/setter pair
order ↔ Int32Value
getter/setter pair
rotationDeg ↔ Int32Value
getter/setter pair
rowVersion RowVersion
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
unknownFields → UnknownFieldSet
no setterinherited

Methods

addExtension(Extension extension, Object? value) → void
Adds an extension field value to a repeated field.
inherited
check() → void
Throws a StateError if the message has required fields without a value.
inherited
clear() → void
Clears all data that was set in this message.
inherited
clearAccountId() → void
clearCropBottomX() → void
clearCropBottomY() → void
clearCropTopX() → void
clearCropTopY() → void
clearExtension(Extension extension) → void
Clears an extension field and also removes the extension.
inherited
clearField(int tagNumber) → void
Clears the contents of a given field.
inherited
clearFullHeight() → void
clearFullWidth() → void
clearImageDataBase64() → void
clearIsAsset() → void
clearName() → void
clearOrder() → void
clearRotationDeg() → void
clearRowVersion() → void
clone() StoredImage
Creates a deep copy of the fields in this message.
copyWith(void updates(StoredImage)) StoredImage
Apply updates to a copy of this message.
createEmptyInstance() StoredImage
Creates an empty instance of the same message type as this.
deepCopy() → T

Available on T, provided by the GeneratedMessageGenericExtensions extension

Returns a writable deep copy of this message.
ensureAccountId() AccountId
ensureCropBottomX() → Int32Value
ensureCropBottomY() → Int32Value
ensureCropTopX() → Int32Value
ensureCropTopY() → Int32Value
ensureFullHeight() → Int32Value
ensureFullWidth() → Int32Value
ensureImageDataBase64() → StringValue
ensureIsAsset() → BoolValue
ensureOrder() → Int32Value
ensureRotationDeg() → Int32Value
ensureRowVersion() RowVersion
extensionsAreInitialized() bool
inherited
freeze() → GeneratedMessage
Make this message read-only.
inherited
getDefaultForField(int tagNumber) → dynamic
Returns the default value for the given field.
inherited
getExtension(Extension extension) → dynamic
Returns the value of extension.
inherited
getField(int tagNumber) → dynamic
Returns the value of the field associated with tagNumber, or the default value if it is not set.
inherited
getFieldOrNull(int tagNumber) → dynamic
Returns the value of a field, ignoring any defaults.
inherited
getTagNumber(String fieldName) int?
inherited
hasAccountId() bool
hasCropBottomX() bool
hasCropBottomY() bool
hasCropTopX() bool
hasCropTopY() bool
hasExtension(Extension extension) bool
Returns true if a value of extension is present.
inherited
hasField(int tagNumber) bool
Whether this message has a field associated with tagNumber.
inherited
hasFullHeight() bool
hasFullWidth() bool
hasImageDataBase64() bool
hasIsAsset() bool
hasName() bool
hasOrder() bool
hasRequiredFields() bool
Whether the message has required fields.
inherited
hasRotationDeg() bool
hasRowVersion() bool
isInitialized() bool
Whether all required fields in the message and embedded messages are set.
inherited
mergeFromBuffer(List<int> input, [ExtensionRegistry extensionRegistry = ExtensionRegistry.EMPTY]) → void
Merges serialized protocol buffer data into this message.
inherited
mergeFromCodedBufferReader(CodedBufferReader input, [ExtensionRegistry extensionRegistry = ExtensionRegistry.EMPTY]) → void
Same as mergeFromBuffer, but takes a CodedBufferReader input.
inherited
mergeFromJson(String data, [ExtensionRegistry extensionRegistry = ExtensionRegistry.EMPTY]) → void
Merges field values from data, a JSON object, encoded as described by GeneratedMessage.writeToJson.
inherited
mergeFromJsonMap(Map<String, dynamic> json, [ExtensionRegistry extensionRegistry = ExtensionRegistry.EMPTY]) → void
Merges field values from a JSON object represented as a Dart map.
inherited
mergeFromMessage(GeneratedMessage other) → void
Merges the contents of the other into this message.
inherited
mergeFromProto3Json(Object? json, {TypeRegistry typeRegistry = const TypeRegistry.empty(), bool ignoreUnknownFields = false, bool supportNamesWithUnderscores = true, bool permissiveEnums = false}) → void
Merges field values from json, a JSON object using proto3 encoding.
inherited
mergeUnknownFields(UnknownFieldSet unknownFieldSet) → void
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebuild(void updates(T)) → T

Available on T, provided by the GeneratedMessageGenericExtensions extension

Apply updates to a copy of this message.
setExtension(Extension extension, Object value) → void
Sets the value of a non-repeated extension field to value.
inherited
setField(int tagNumber, Object value) → void
Sets the value of a field by its tagNumber.
inherited
toBuilder() → GeneratedMessage
Creates a writable, shallow copy of this message.
inherited
toDebugString() String
Returns a String representation of this message.
inherited
toProto3Json({TypeRegistry typeRegistry = const TypeRegistry.empty()}) Object?
Returns an Object representing Proto3 JSON serialization of this.
inherited
toString() String
Returns a String representation of this message.
inherited
writeToBuffer() Uint8List
Serialize the message as the protobuf binary format.
inherited
writeToCodedBufferWriter(CodedBufferWriter output) → void
Same as writeToBuffer, but serializes to the given CodedBufferWriter.
inherited
writeToJson() String
Returns a JSON string that encodes this message.
inherited
writeToJsonMap() Map<String, dynamic>
Returns the JSON encoding of this message as a Dart Map.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

create() StoredImage
getDefault() StoredImage