StoredImageServiceBase class abstract

Annotations
  • @GrpcServiceName.new('StoredImageService')

Constructors

StoredImageServiceBase()

Properties

$name String
no setter
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

$addMethod(ServiceMethod method) → void
inherited
$lookupMethod(String name) → ServiceMethod?
inherited
$onMetadata(ServiceCall context) → void
Client metadata handler.
inherited
list(ServiceCall call, StoredImageQuery request) Future<PageResult>
list_Pre(ServiceCall $call, Future<StoredImageQuery> $request) Future<PageResult>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited
upsert(ServiceCall call, StoredImage request) Future<StoredImage>
upsert_Pre(ServiceCall $call, Future<StoredImage> $request) Future<StoredImage>

Operators

operator ==(Object other) bool
The equality operator.
inherited