SubscriptionServiceClient class

Annotations
  • @GrpcServiceName.new('SubscriptionService')

Constructors

SubscriptionServiceClient(ClientChannel channel, {CallOptions? options, Iterable<ClientInterceptor>? interceptors})

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

$createCall<Q, R>(ClientMethod<Q, R> method, Stream<Q> requests, {CallOptions? options}) → ClientCall<Q, R>
inherited
$createStreamingCall<Q, R>(ClientMethod<Q, R> method, Stream<Q> requests, {CallOptions? options}) → ResponseStream<R>
inherited
$createUnaryCall<Q, R>(ClientMethod<Q, R> method, Q request, {CallOptions? options}) → ResponseFuture<R>
inherited
create(Subscription request, {CallOptions? options}) → ResponseFuture<Subscription>
get(SubscriptionId request, {CallOptions? options}) → ResponseFuture<Subscription>
getDefaultSubscription(Empty request, {CallOptions? options}) → ResponseFuture<Subscription>
getSubscriptionForAccount(AccountId request, {CallOptions? options}) → ResponseFuture<Subscription>
list(SubscriptionQuery request, {CallOptions? options}) → ResponseFuture<PageResult>
Subscriptions: List Subscription
listSubscribers(SubscriberQuery request, {CallOptions? options}) → ResponseFuture<PageResult>
Subscriptions: List Subscribers Subscriber
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited
update(Subscription request, {CallOptions? options}) → ResponseFuture<Subscription>

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

defaultHost → const String
The hostname for this service.
oauthScopes → const List<String>
OAuth scopes needed for the client.