SwipBoxCourierServiceBase class abstract

Annotations
  • @GrpcServiceName.new('SwipBoxCourierService')

Constructors

SwipBoxCourierServiceBase()

Properties

$name String
no setter
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

$addMethod(ServiceMethod method) → void
inherited
$lookupMethod(String name) → ServiceMethod?
inherited
$onMetadata(ServiceCall context) → void
Client metadata handler.
inherited
get(ServiceCall call, SwipBoxServicePointId request) Future<Shipments>
get_Pre(ServiceCall $call, Future<SwipBoxServicePointId> $request) Future<Shipments>
listShipments(ServiceCall call, SwipBoxServicePointQuery request) Future<PageResult>
listShipments_Pre(ServiceCall $call, Future<SwipBoxServicePointQuery> $request) Future<PageResult>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
pickupComplete(ServiceCall call, PickupCompleteRequest request) Future<PickupCompleteResponse>
pickupComplete_Pre(ServiceCall $call, Future<PickupCompleteRequest> $request) Future<PickupCompleteResponse>
servicePointComplete(ServiceCall call, SwipBoxShipmentCompleteRequest request) Future<SwipBoxShipmentCompleteResponse>
servicePointComplete_Pre(ServiceCall $call, Future<SwipBoxShipmentCompleteRequest> $request) Future<SwipBoxShipmentCompleteResponse>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited