SwipBoxCourierServiceClient class
- Annotations
-
- @GrpcServiceName.new('SwipBoxCourierService')
Properties
-
hashCode
→ int
-
The hash code for this object.
no setterinherited
-
runtimeType
→ Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
$createCall<Q, R>(ClientMethod<Q, R> method, Stream<Q> requests, {CallOptions? options})
→ ClientCall<Q, R>
-
inherited
-
$createStreamingCall<Q, R>(ClientMethod<Q, R> method, Stream<Q> requests, {CallOptions? options})
→ ResponseStream<R>
-
inherited
-
$createUnaryCall<Q, R>(ClientMethod<Q, R> method, Q request, {CallOptions? options})
→ ResponseFuture<R>
-
inherited
-
get(SwipBoxServicePointId request, {CallOptions? options})
→ ResponseFuture<Shipments>
-
-
listShipments(SwipBoxServicePointQuery request, {CallOptions? options})
→ ResponseFuture<PageResult>
-
SwipBox: List Shipments Shipment
-
noSuchMethod(Invocation invocation)
→ dynamic
-
Invoked when a nonexistent method or property is accessed.
inherited
-
pickupComplete(PickupCompleteRequest request, {CallOptions? options})
→ ResponseFuture<PickupCompleteResponse>
-
-
servicePointComplete(SwipBoxShipmentCompleteRequest request, {CallOptions? options})
→ ResponseFuture<SwipBoxShipmentCompleteResponse>
-
-
toString()
→ String
-
A string representation of this object.
inherited