SwipBoxEnduserServiceBase class abstract

Annotations
  • @GrpcServiceName.new('SwipBoxEnduserService')

Constructors

SwipBoxEnduserServiceBase()

Properties

$name String
no setter
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

$addMethod(ServiceMethod method) → void
inherited
$lookupMethod(String name) → ServiceMethod?
inherited
$onMetadata(ServiceCall context) → void
Client metadata handler.
inherited
bookReturn(ServiceCall call, BookReturnRequest request) Future<BookReturnResponse>
bookReturn_Pre(ServiceCall $call, Future<BookReturnRequest> $request) Future<BookReturnResponse>
cancel(ServiceCall call, CancelShipmentRequest request) Future<CancelShipmentResponse>
cancel_Pre(ServiceCall $call, Future<CancelShipmentRequest> $request) Future<CancelShipmentResponse>
getCapacity(ServiceCall call, SwipBoxServicePointId request) Future<CapacityResult>
getCapacity_Pre(ServiceCall $call, Future<SwipBoxServicePointId> $request) Future<CapacityResult>
getToken(ServiceCall call, TokenRequest request) Future<TokenResponse>
getToken_Pre(ServiceCall $call, Future<TokenRequest> $request) Future<TokenResponse>
listServicePoints(ServiceCall call, SwipBoxServicePointQuery request) Future<ServicePointList>
listServicePoints_Pre(ServiceCall $call, Future<SwipBoxServicePointQuery> $request) Future<ServicePointList>
listShipments(ServiceCall call, SwipBoxEnduserShipmentQuery request) Future<SwipBoxEnduserShipmentsResult>
listShipments_Pre(ServiceCall $call, Future<SwipBoxEnduserShipmentQuery> $request) Future<SwipBoxEnduserShipmentsResult>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
returnComplete(ServiceCall call, ReturnCompleteRequest request) Future<ReturnCompleteResponse>
returnComplete_Pre(ServiceCall $call, Future<ReturnCompleteRequest> $request) Future<ReturnCompleteResponse>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited