TemplateServiceBase class abstract

Annotations
  • @GrpcServiceName.new('TemplateService')

Constructors

TemplateServiceBase()

Properties

$name String
no setter
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

$addMethod(ServiceMethod method) → void
inherited
$lookupMethod(String name) → ServiceMethod?
inherited
$onMetadata(ServiceCall context) → void
Client metadata handler.
inherited
get(ServiceCall call, TemplateId request) Future<Template>
get_Pre(ServiceCall $call, Future<TemplateId> $request) Future<Template>
list(ServiceCall call, TemplateQuery request) Future<PageResult>
list_Pre(ServiceCall $call, Future<TemplateQuery> $request) Future<PageResult>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited
upsert(ServiceCall call, Template request) Future<Template>
upsert_Pre(ServiceCall $call, Future<Template> $request) Future<Template>

Operators

operator ==(Object other) bool
The equality operator.
inherited