TrackingServiceBase class abstract

Annotations
  • @GrpcServiceName.new('TrackingService')

Constructors

TrackingServiceBase()

Properties

$name String
no setter
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

$addMethod(ServiceMethod method) → void
inherited
$lookupMethod(String name) → ServiceMethod?
inherited
$onMetadata(ServiceCall context) → void
Client metadata handler.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited
track(ServiceCall call, TrackingEvent request) Future<Empty>
track_Pre(ServiceCall $call, Future<TrackingEvent> $request) Future<Empty>
trackBatch(ServiceCall call, TrackingBatch request) Future<Empty>
trackBatch_Pre(ServiceCall $call, Future<TrackingBatch> $request) Future<Empty>

Operators

operator ==(Object other) bool
The equality operator.
inherited