proto/UI.pb library

Classes

UIAlignment
UIAnimation
UIAnimationCurve
Easing curve, maps nicely to both Flutter Curves and CSS timing functions.
UIAnimationPreset
What kind of animation (think Tailwind/Framer “presets”).
UIAnimationTrigger
When to start the animation.
UIBanner
UIBlock
UIBlockHeader
UIBlockQuery
UIBorder
UIBorderStyle
UIButton
UIButton_UIButtonVariant
UIColorRef
UIColumn
UIContext
UIDivider
UIEdgeInsets
UIElement
UIElementQuery
UIElementType
UIExpando
UIFlowComponent
Flow layout that wraps items based on a fixed item width
UIFooter
UIHorizontalScroll
UIHtml
UIImage
UIImage_UIImageFit
UIInlineStyle
=== Inline styling for rich text ===
UILength
UILinkSpan
Link wrapper that can also carry style overrides (underline/color/etc.)
UIList
UIList_UIListType
UIMenu
UIObjectFit
---------- Layout enums ----------
UIParagraph
A paragraph block containing inline spans
UIProductCollection
UIProductCollection_CollectionView
UIProductDetails
UIProductPlacehoder
UIRichText
Rich text block (one or more paragraphs)
UIRow
ROW / COLUMN (flex)
UISection
UISizeConstraints
UISpan
UIStack
UIStyle
---------- Content model ----------
UISwiper
UITab
UITabView
UIText
UIText_TextAlign
UIText_TextSize
UITextAlign
UITextSize
UITheme
UIUnit
UIVideo
UIVideoProvider

Extensions

GeneratedMessageGenericExtensions on T
Extensions on GeneratedMessages.