UIAnimationCurve class
Easing curve, maps nicely to both Flutter Curves and CSS timing functions.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- name → String
-
This enum's name, as specified in the .proto file.
finalinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- value → int
-
This enum's integer value, as specified in the .proto file.
finalinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
Returns this enum's
nameor thevalueif names are not represented.inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
valueOf(
int value) → UIAnimationCurve?
Constants
- UIANIM_CURVE_EASE → const UIAnimationCurve
- UIANIM_CURVE_EASE_IN → const UIAnimationCurve
- UIANIM_CURVE_EASE_IN_OUT → const UIAnimationCurve
- UIANIM_CURVE_EASE_OUT → const UIAnimationCurve
- UIANIM_CURVE_LINEAR → const UIAnimationCurve
-
values
→ const List<
UIAnimationCurve>