UIAnimationPreset class
What kind of animation (think Tailwind/Framer “presets”).
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- name → String
-
This enum's name, as specified in the .proto file.
finalinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- value → int
-
This enum's integer value, as specified in the .proto file.
finalinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
Returns this enum's
nameor thevalueif names are not represented.inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
valueOf(
int value) → UIAnimationPreset?
Constants
- UIANIM_PRESET_FADE_IN → const UIAnimationPreset
- UIANIM_PRESET_FADE_IN_DOWN → const UIAnimationPreset
- UIANIM_PRESET_FADE_IN_LEFT → const UIAnimationPreset
- UIANIM_PRESET_FADE_IN_RIGHT → const UIAnimationPreset
- UIANIM_PRESET_FADE_IN_UP → const UIAnimationPreset
- UIANIM_PRESET_SCALE_IN → const UIAnimationPreset
- UIANIM_PRESET_UNSPECIFIED → const UIAnimationPreset
-
values
→ const List<
UIAnimationPreset>