UIBlockServiceBase class abstract

Annotations
  • @GrpcServiceName.new('UIBlockService')

Constructors

UIBlockServiceBase()

Properties

$name String
no setter
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

$addMethod(ServiceMethod method) → void
inherited
$lookupMethod(String name) → ServiceMethod?
inherited
$onMetadata(ServiceCall context) → void
Client metadata handler.
inherited
get(ServiceCall call, UIBlockId request) Future<UIBlock>
get_Pre(ServiceCall $call, Future<UIBlockId> $request) Future<UIBlock>
list(ServiceCall call, UIBlockQuery request) Future<PageResult>
list_Pre(ServiceCall $call, Future<UIBlockQuery> $request) Future<PageResult>
listElementTypes(ServiceCall call, UIElementQuery request) Future<PageResult>
listElementTypes_Pre(ServiceCall $call, Future<UIElementQuery> $request) Future<PageResult>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited
upsert(ServiceCall call, UIBlock request) Future<UIBlock>
upsert_Pre(ServiceCall $call, Future<UIBlock> $request) Future<UIBlock>

Operators

operator ==(Object other) bool
The equality operator.
inherited