VoucherServiceClient class

Annotations
  • @GrpcServiceName.new('VoucherService')

Constructors

VoucherServiceClient(ClientChannel channel, {CallOptions? options, Iterable<ClientInterceptor>? interceptors})

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

$createCall<Q, R>(ClientMethod<Q, R> method, Stream<Q> requests, {CallOptions? options}) → ClientCall<Q, R>
inherited
$createStreamingCall<Q, R>(ClientMethod<Q, R> method, Stream<Q> requests, {CallOptions? options}) → ResponseStream<R>
inherited
$createUnaryCall<Q, R>(ClientMethod<Q, R> method, Q request, {CallOptions? options}) → ResponseFuture<R>
inherited
claimVoucher(ClaimVoucherRequest request, {CallOptions? options}) → ResponseFuture<ClaimVoucherResponse>
Vouchers: Claim
create(Voucher request, {CallOptions? options}) → ResponseFuture<Voucher>
Vouchers: Create
delete(VoucherCode request, {CallOptions? options}) → ResponseFuture<Empty>
Vouchers: Delete
get(VoucherCode request, {CallOptions? options}) → ResponseFuture<Voucher>
Vouchers: Get
getStatus(VoucherStatusRequest request, {CallOptions? options}) → ResponseFuture<VoucherStatusResponse>
Vouchers: Get Status
list(VoucherQuery request, {CallOptions? options}) → ResponseFuture<PageResult>
Vouchers: List VoucherHeader
listRules(VoucherRuleQuery request, {CallOptions? options}) → ResponseFuture<PageResult>
Vouchers: List Rules VoucherRule
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited
update(Voucher request, {CallOptions? options}) → ResponseFuture<Voucher>
Vouchers: Update

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

defaultHost → const String
The hostname for this service.
oauthScopes → const List<String>
OAuth scopes needed for the client.