- Annotations
-
- @GrpcServiceName.new('AccountService')
Properties
-
$name
→ String
-
no setter
-
hashCode
→ int
-
The hash code for this object.
no setterinherited
-
runtimeType
→ Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
$addMethod(ServiceMethod method)
→ void
-
inherited
-
$lookupMethod(String name)
→ ServiceMethod?
-
inherited
-
$onMetadata(ServiceCall context)
→ void
-
Client metadata handler.
inherited
-
create(ServiceCall call, Account request)
→ Future<Account>
-
-
create_Pre(ServiceCall $call, Future<Account> $request)
→ Future<Account>
-
-
delete(ServiceCall call, AccountId request)
→ Future<Empty>
-
-
delete_Pre(ServiceCall $call, Future<AccountId> $request)
→ Future<Empty>
-
-
follow(ServiceCall call, FollowRequest request)
→ Future<FollowResponse>
-
-
follow_Pre(ServiceCall $call, Future<FollowRequest> $request)
→ Future<FollowResponse>
-
-
get(ServiceCall call, AccountId request)
→ Future<AccountInfo>
-
-
get_Pre(ServiceCall $call, Future<AccountId> $request)
→ Future<AccountInfo>
-
-
getProfile(ServiceCall call, AccountProfileRequest request)
→ Future<AccountProfileInfo>
-
-
getProfile_Pre(ServiceCall $call, Future<AccountProfileRequest> $request)
→ Future<AccountProfileInfo>
-
-
getPublicProfile(ServiceCall call, UUID request)
→ Future<AccountPublicProfile>
-
-
getPublicProfile_Pre(ServiceCall $call, Future<UUID> $request)
→ Future<AccountPublicProfile>
-
-
getStatus(ServiceCall call, AccountStatusRequest request)
→ Future<AccountStatusResponse>
-
-
getStatus_Pre(ServiceCall $call, Future<AccountStatusRequest> $request)
→ Future<AccountStatusResponse>
-
-
list(ServiceCall call, AccountQuery request)
→ Future<PageResult>
-
-
list_Pre(ServiceCall $call, Future<AccountQuery> $request)
→ Future<PageResult>
-
-
listFollows(ServiceCall call, FollowQuery request)
→ Future<PageResult>
-
-
listFollows_Pre(ServiceCall $call, Future<FollowQuery> $request)
→ Future<PageResult>
-
-
noSuchMethod(Invocation invocation)
→ dynamic
-
Invoked when a nonexistent method or property is accessed.
inherited
-
toString()
→ String
-
A string representation of this object.
inherited
-
unFollow(ServiceCall call, UnFollowRequest request)
→ Future<UnFollowResponse>
-
-
unFollow_Pre(ServiceCall $call, Future<UnFollowRequest> $request)
→ Future<UnFollowResponse>
-
-
update(ServiceCall call, Account request)
→ Future<Account>
-
-
update_Pre(ServiceCall $call, Future<Account> $request)
→ Future<Account>
-
-
verify(ServiceCall call, AccountVerificationRequest request)
→ Future<AccountVerificationResponse>
-
-
verify_Pre(ServiceCall $call, Future<AccountVerificationRequest> $request)
→ Future<AccountVerificationResponse>
-