CollectionServiceClient class
- Annotations
-
- @GrpcServiceName.new('CollectionService')
Properties
-
hashCode
→ int
-
The hash code for this object.
no setterinherited
-
runtimeType
→ Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
$createCall<Q, R>(ClientMethod<Q, R> method, Stream<Q> requests, {CallOptions? options})
→ ClientCall<Q, R>
-
inherited
-
$createStreamingCall<Q, R>(ClientMethod<Q, R> method, Stream<Q> requests, {CallOptions? options})
→ ResponseStream<R>
-
inherited
-
$createUnaryCall<Q, R>(ClientMethod<Q, R> method, Q request, {CallOptions? options})
→ ResponseFuture<R>
-
inherited
-
addObjects(CollectionObjects request, {CallOptions? options})
→ ResponseFuture<Empty>
-
-
create(Collection request, {CallOptions? options})
→ ResponseFuture<Collection>
-
-
delete(CollectionId request, {CallOptions? options})
→ ResponseFuture<Empty>
-
-
get(CollectionId request, {CallOptions? options})
→ ResponseFuture<Collection>
-
-
list(CollectionQuery request, {CallOptions? options})
→ ResponseFuture<PageResult>
-
Collections: List Collections Collection
-
listObjects(CollectionObjectQuery request, {CallOptions? options})
→ ResponseFuture<PageResult>
-
Collections: List Objects SearchObject
-
noSuchMethod(Invocation invocation)
→ dynamic
-
Invoked when a nonexistent method or property is accessed.
inherited
-
removeObjects(CollectionObjects request, {CallOptions? options})
→ ResponseFuture<Empty>
-
-
toString()
→ String
-
A string representation of this object.
inherited
-
update(Collection request, {CallOptions? options})
→ ResponseFuture<Collection>
-