FeedServiceClient class
Feed Service
- Annotations
-
- @GrpcServiceName.new('FeedService')
Constructors
-
FeedServiceClient(ClientChannel channel, {CallOptions? options, Iterable<
ClientInterceptor> ? interceptors})
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
$createCall<
Q, R> (ClientMethod< Q, R> method, Stream<Q> requests, {CallOptions? options}) → ClientCall<Q, R> -
inherited
-
$createStreamingCall<
Q, R> (ClientMethod< Q, R> method, Stream<Q> requests, {CallOptions? options}) → ResponseStream<R> -
inherited
-
$createUnaryCall<
Q, R> (ClientMethod< Q, R> method, Q request, {CallOptions? options}) → ResponseFuture<R> -
inherited
-
delete(
FeedItemId request, {CallOptions? options}) → ResponseFuture< Empty> -
getStatus(
FeedStatusRequest request, {CallOptions? options}) → ResponseFuture< FeedStatusResponse> -
getUrlMapping(
UrlMappingRequest request, {CallOptions? options}) → ResponseFuture< UrlMappingResponse> -
list(
FeedQuery request, {CallOptions? options}) → ResponseFuture< PageResult> - Feed: List Feed Items FeedItem
-
listStatic(
FeedQuery request, {CallOptions? options}) → ResponseFuture< PageResult> - Feed: List Static Feed Items FeedItem
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
upsert(
FeedItem request, {CallOptions? options}) → ResponseFuture< FeedItem> - Feed: Create Feed Entry
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- defaultHost → const String
- The hostname for this service.
-
oauthScopes
→ const List<
String> - OAuth scopes needed for the client.