BookMetadata class
- Available extensions
Constructors
-
BookMetadata({Barcode? iSBN13, StringValue? title, StringValue? subTitle, StringValue? description, Iterable<
StringValue> ? authors, StringValue? publisher, Int32Value? publishingYear, Int32Value? pages, StringValue? language, Int32Value? estimatedThicknessInMM, StringValue? type, StringValue? languageIso, StringValue? summary, Iterable<StringValue> ? reviews, Int32Value? conditionPct, StringValue? conditionDescription, StringValue? genre, StringValue? category, StringValue? edition}) -
factory
-
BookMetadata.fromBuffer(List<
int> data, [ExtensionRegistry registry = $pb.ExtensionRegistry.EMPTY]) -
factory
- BookMetadata.fromJson(String json, [ExtensionRegistry registry = $pb.ExtensionRegistry.EMPTY])
-
factory
Properties
-
no setter
- category ↔ StringValue
-
Fiction, Non-fiction, Childre, Study ...
getter/setter pair
- conditionDescription ↔ StringValue
-
getter/setter pair
- conditionPct ↔ Int32Value
-
getter/setter pair
- description ↔ StringValue
-
getter/setter pair
- edition ↔ StringValue
-
getter/setter pair
- estimatedThicknessInMM ↔ Int32Value
-
getter/setter pair
- genre ↔ StringValue
-
Litteraty genre. Romance, Crime, ...
getter/setter pair
- hashCode → int
-
Calculates a hash code based on the contents of the protobuf.
no setterinherited
- info_ → BuilderInfo
-
no setter
- iSBN13 ↔ Barcode
-
getter/setter pair
- isFrozen → bool
-
Returns
trueif this message is marked read-only. Otherwisefalse.no setterinherited - language ↔ StringValue
-
Danish, English, etc
getter/setter pair
- languageIso ↔ StringValue
-
da, en, se, ...
getter/setter pair
- pages ↔ Int32Value
-
getter/setter pair
- publisher ↔ StringValue
-
getter/setter pair
- publishingYear ↔ Int32Value
-
getter/setter pair
-
reviews
→ PbList<
StringValue> -
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- subTitle ↔ StringValue
-
getter/setter pair
- summary ↔ StringValue
-
getter/setter pair
- title ↔ StringValue
-
getter/setter pair
- type ↔ StringValue
-
Hard back, paper back, magazine, cartoon
getter/setter pair
- unknownFields → UnknownFieldSet
-
no setterinherited
Methods
-
addExtension(
Extension extension, Object? value) → void -
Adds an extension field value to a repeated field.
inherited
-
check(
) → void -
Throws a StateError if the message has required fields without a value.
inherited
-
clear(
) → void -
Clears all data that was set in this message.
inherited
-
clearCategory(
) → void -
clearConditionDescription(
) → void -
clearConditionPct(
) → void -
clearDescription(
) → void -
clearEdition(
) → void -
clearEstimatedThicknessInMM(
) → void -
clearExtension(
Extension extension) → void -
Clears an extension field and also removes the extension.
inherited
-
clearField(
int tagNumber) → void -
Clears the contents of a given field.
inherited
-
clearGenre(
) → void -
clearISBN13(
) → void -
clearLanguage(
) → void -
clearLanguageIso(
) → void -
clearPages(
) → void -
clearPublisher(
) → void -
clearPublishingYear(
) → void -
clearSubTitle(
) → void -
clearSummary(
) → void -
clearTitle(
) → void -
clearType(
) → void -
clone(
) → BookMetadata - Creates a deep copy of the fields in this message.
-
copyWith(
void updates(BookMetadata)) → BookMetadata -
Apply
updatesto a copy of this message. -
createEmptyInstance(
) → BookMetadata - Creates an empty instance of the same message type as this.
-
deepCopy(
) → T -
Available on T, provided by the GeneratedMessageGenericExtensions extension
Returns a writable deep copy of this message. -
ensureCategory(
) → StringValue -
ensureConditionDescription(
) → StringValue -
ensureConditionPct(
) → Int32Value -
ensureDescription(
) → StringValue -
ensureEdition(
) → StringValue -
ensureEstimatedThicknessInMM(
) → Int32Value -
ensureGenre(
) → StringValue -
ensureISBN13(
) → Barcode -
ensureLanguage(
) → StringValue -
ensureLanguageIso(
) → StringValue -
ensurePages(
) → Int32Value -
ensurePublisher(
) → StringValue -
ensurePublishingYear(
) → Int32Value -
ensureSubTitle(
) → StringValue -
ensureSummary(
) → StringValue -
ensureTitle(
) → StringValue -
ensureType(
) → StringValue -
extensionsAreInitialized(
) → bool -
inherited
-
freeze(
) → GeneratedMessage -
Make this message read-only.
inherited
-
getDefaultForField(
int tagNumber) → dynamic -
Returns the default value for the given field.
inherited
-
getExtension(
Extension extension) → dynamic -
Returns the value of
extension.inherited -
getField(
int tagNumber) → dynamic -
Returns the value of the field associated with
tagNumber, or the default value if it is not set.inherited -
getFieldOrNull(
int tagNumber) → dynamic -
Returns the value of a field, ignoring any defaults.
inherited
-
getTagNumber(
String fieldName) → int? -
inherited
-
hasCategory(
) → bool -
hasConditionDescription(
) → bool -
hasConditionPct(
) → bool -
hasDescription(
) → bool -
hasEdition(
) → bool -
hasEstimatedThicknessInMM(
) → bool -
hasExtension(
Extension extension) → bool -
Returns
trueif a value ofextensionis present.inherited -
hasField(
int tagNumber) → bool -
Whether this message has a field associated with
tagNumber.inherited -
hasGenre(
) → bool -
hasISBN13(
) → bool -
hasLanguage(
) → bool -
hasLanguageIso(
) → bool -
hasPages(
) → bool -
hasPublisher(
) → bool -
hasPublishingYear(
) → bool -
hasRequiredFields(
) → bool -
Whether the message has required fields.
inherited
-
hasSubTitle(
) → bool -
hasSummary(
) → bool -
hasTitle(
) → bool -
hasType(
) → bool -
isInitialized(
) → bool -
Whether all required fields in the message and embedded messages are set.
inherited
-
mergeFromBuffer(
List< int> input, [ExtensionRegistry extensionRegistry = ExtensionRegistry.EMPTY]) → void -
Merges serialized protocol buffer data into this message.
inherited
-
mergeFromCodedBufferReader(
CodedBufferReader input, [ExtensionRegistry extensionRegistry = ExtensionRegistry.EMPTY]) → void -
Same as
mergeFromBuffer, but takes aCodedBufferReaderinput.inherited -
mergeFromJson(
String data, [ExtensionRegistry extensionRegistry = ExtensionRegistry.EMPTY]) → void -
Merges field values from
data, a JSON object, encoded as described byGeneratedMessage.writeToJson.inherited -
mergeFromJsonMap(
Map< String, dynamic> json, [ExtensionRegistry extensionRegistry = ExtensionRegistry.EMPTY]) → void -
Merges field values from a JSON object represented as a Dart map.
inherited
-
mergeFromMessage(
GeneratedMessage other) → void -
Merges the contents of the
otherinto this message.inherited -
mergeFromProto3Json(
Object? json, {TypeRegistry typeRegistry = const TypeRegistry.empty(), bool ignoreUnknownFields = false, bool supportNamesWithUnderscores = true, bool permissiveEnums = false}) → void -
Merges field values from
json, a JSON object using proto3 encoding.inherited -
mergeUnknownFields(
UnknownFieldSet unknownFieldSet) → void -
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
rebuild(
void updates(T)) → T -
Available on T, provided by the GeneratedMessageGenericExtensions extension
Applyupdatesto a copy of this message. -
setExtension(
Extension extension, Object value) → void -
Sets the value of a non-repeated extension field to
value.inherited -
setField(
int tagNumber, Object value) → void -
Sets the value of a field by its
tagNumber.inherited -
toBuilder(
) → GeneratedMessage -
Creates a writable, shallow copy of this message.
inherited
-
toDebugString(
) → String -
Returns a String representation of this message.
inherited
-
toProto3Json(
{TypeRegistry typeRegistry = const TypeRegistry.empty()}) → Object? -
Returns an Object representing Proto3 JSON serialization of
this.inherited -
toString(
) → String -
Returns a String representation of this message.
inherited
-
writeToBuffer(
) → Uint8List -
Serialize the message as the protobuf binary format.
inherited
-
writeToCodedBufferWriter(
CodedBufferWriter output) → void -
Same as
writeToBuffer, but serializes to the givenCodedBufferWriter.inherited -
writeToJson(
) → String -
Returns a JSON string that encodes this message.
inherited
-
writeToJsonMap(
) → Map< String, dynamic> -
Returns the JSON encoding of this message as a Dart Map.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
create(
) → BookMetadata -
getDefault(
) → BookMetadata