RoleServiceClient class
- Annotations
-
- @GrpcServiceName.new('RoleService')
Properties
-
hashCode
→ int
-
The hash code for this object.
no setterinherited
-
runtimeType
→ Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
$createCall<Q, R>(ClientMethod<Q, R> method, Stream<Q> requests, {CallOptions? options})
→ ClientCall<Q, R>
-
inherited
-
$createStreamingCall<Q, R>(ClientMethod<Q, R> method, Stream<Q> requests, {CallOptions? options})
→ ResponseStream<R>
-
inherited
-
$createUnaryCall<Q, R>(ClientMethod<Q, R> method, Q request, {CallOptions? options})
→ ResponseFuture<R>
-
inherited
-
createPermission(RolePermission request, {CallOptions? options})
→ ResponseFuture<RolePermission>
-
-
createPermissions(RolePermissionList request, {CallOptions? options})
→ ResponseFuture<RolePermissionList>
-
-
createRole(RoleHeader request, {CallOptions? options})
→ ResponseFuture<RoleHeader>
-
-
deletePermission(RolePermission request, {CallOptions? options})
→ ResponseFuture<Empty>
-
-
deleteRole(Role request, {CallOptions? options})
→ ResponseFuture<Empty>
-
-
listPermissionErrors(PermissionErrorQuery request, {CallOptions? options})
→ ResponseFuture<PageResult>
-
Roles: List Permission Errors PermissionError
-
listPermissions(RolePermissionQuery request, {CallOptions? options})
→ ResponseFuture<PageResult>
-
Roles: List Permissions RolePermission
-
listRoles(RoleQuery request, {CallOptions? options})
→ ResponseFuture<PageResult>
-
Roles: List Roles RoleHeader
-
noSuchMethod(Invocation invocation)
→ dynamic
-
Invoked when a nonexistent method or property is accessed.
inherited
-
toString()
→ String
-
A string representation of this object.
inherited