ScannerBarcode_Barcode enum
Values
- accountId → const ScannerBarcode_Barcode
- containerId → const ScannerBarcode_Barcode
- transportId → const ScannerBarcode_Barcode
- iSBN → const ScannerBarcode_Barcode
- product → const ScannerBarcode_Barcode
- unknown → const ScannerBarcode_Barcode
- trashId → const ScannerBarcode_Barcode
- notSet → const ScannerBarcode_Barcode
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
ScannerBarcode_Barcode> - A constant List of the values in this enum, in order of their declaration.