- Annotations
-
- @GrpcServiceName.new('StatisticsService')
Properties
-
$name
→ String
-
no setter
-
hashCode
→ int
-
The hash code for this object.
no setterinherited
-
runtimeType
→ Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
$addMethod(ServiceMethod method)
→ void
-
inherited
-
$lookupMethod(String name)
→ ServiceMethod?
-
inherited
-
$onMetadata(ServiceCall context)
→ void
-
Client metadata handler.
inherited
-
deleteChart(ServiceCall call, ChartId request)
→ Future<Empty>
-
-
deleteChart_Pre(ServiceCall $call, Future<ChartId> $request)
→ Future<Empty>
-
-
getChart(ServiceCall call, ChartId request)
→ Future<Chart>
-
-
getChart_Pre(ServiceCall $call, Future<ChartId> $request)
→ Future<Chart>
-
-
list(ServiceCall call, StatisticsQuery request)
→ Future<PageResult>
-
-
list_Pre(ServiceCall $call, Future<StatisticsQuery> $request)
→ Future<PageResult>
-
-
listCharts(ServiceCall call, ChartQuery request)
→ Future<PageResult>
-
-
listCharts_Pre(ServiceCall $call, Future<ChartQuery> $request)
→ Future<PageResult>
-
-
listDescriptors(ServiceCall call, StatisticDescriptorQuery request)
→ Future<PageResult>
-
-
listDescriptors_Pre(ServiceCall $call, Future<StatisticDescriptorQuery> $request)
→ Future<PageResult>
-
-
noSuchMethod(Invocation invocation)
→ dynamic
-
Invoked when a nonexistent method or property is accessed.
inherited
-
toString()
→ String
-
A string representation of this object.
inherited
-
upsertChart(ServiceCall call, Chart request)
→ Future<Chart>
-
-
upsertChart_Pre(ServiceCall $call, Future<Chart> $request)
→ Future<Chart>
-