- Annotations
-
- @GrpcServiceName.new('StoredObjectService')
Properties
-
$name
→ String
-
no setter
-
hashCode
→ int
-
The hash code for this object.
no setterinherited
-
runtimeType
→ Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
$addMethod(ServiceMethod method)
→ void
-
inherited
-
$lookupMethod(String name)
→ ServiceMethod?
-
inherited
-
$onMetadata(ServiceCall context)
→ void
-
Client metadata handler.
inherited
-
create(ServiceCall call, StoredObject request)
→ Future<StoredObject>
-
-
create_Pre(ServiceCall $call, Future<StoredObject> $request)
→ Future<StoredObject>
-
-
delete(ServiceCall call, StoredObjectId request)
→ Future<Empty>
-
-
delete_Pre(ServiceCall $call, Future<StoredObjectId> $request)
→ Future<Empty>
-
-
get(ServiceCall call, StoredObjectId request)
→ Future<StoredObject>
-
-
get_Pre(ServiceCall $call, Future<StoredObjectId> $request)
→ Future<StoredObject>
-
-
history(ServiceCall call, ObjectHistoryQuery request)
→ Future<PageResult>
-
-
history_Pre(ServiceCall $call, Future<ObjectHistoryQuery> $request)
→ Future<PageResult>
-
-
list(ServiceCall call, ObjectQuery request)
→ Future<PageResult>
-
-
list_Pre(ServiceCall $call, Future<ObjectQuery> $request)
→ Future<PageResult>
-
-
noSuchMethod(Invocation invocation)
→ dynamic
-
Invoked when a nonexistent method or property is accessed.
inherited
-
toString()
→ String
-
A string representation of this object.
inherited
-
transferObjects(ServiceCall call, TransferObjectsRequest request)
→ Future<TransferObjectsResponse>
-
-
transferObjects_Pre(ServiceCall $call, Future<TransferObjectsRequest> $request)
→ Future<TransferObjectsResponse>
-
-
update(ServiceCall call, StoredObject request)
→ Future<StoredObject>
-
-
update_Pre(ServiceCall $call, Future<StoredObject> $request)
→ Future<StoredObject>
-