- Annotations
-
- @GrpcServiceName.new('SubscriptionService')
Properties
-
$name
→ String
-
no setter
-
hashCode
→ int
-
The hash code for this object.
no setterinherited
-
runtimeType
→ Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
$addMethod(ServiceMethod method)
→ void
-
inherited
-
$lookupMethod(String name)
→ ServiceMethod?
-
inherited
-
$onMetadata(ServiceCall context)
→ void
-
Client metadata handler.
inherited
-
create(ServiceCall call, Subscription request)
→ Future<Subscription>
-
-
create_Pre(ServiceCall $call, Future<Subscription> $request)
→ Future<Subscription>
-
-
get(ServiceCall call, SubscriptionId request)
→ Future<Subscription>
-
-
get_Pre(ServiceCall $call, Future<SubscriptionId> $request)
→ Future<Subscription>
-
-
getDefaultSubscription(ServiceCall call, Empty request)
→ Future<Subscription>
-
-
getDefaultSubscription_Pre(ServiceCall $call, Future<Empty> $request)
→ Future<Subscription>
-
-
getSubscriptionForAccount(ServiceCall call, AccountId request)
→ Future<Subscription>
-
-
getSubscriptionForAccount_Pre(ServiceCall $call, Future<AccountId> $request)
→ Future<Subscription>
-
-
list(ServiceCall call, SubscriptionQuery request)
→ Future<PageResult>
-
-
list_Pre(ServiceCall $call, Future<SubscriptionQuery> $request)
→ Future<PageResult>
-
-
listSubscribers(ServiceCall call, SubscriberQuery request)
→ Future<PageResult>
-
-
listSubscribers_Pre(ServiceCall $call, Future<SubscriberQuery> $request)
→ Future<PageResult>
-
-
noSuchMethod(Invocation invocation)
→ dynamic
-
Invoked when a nonexistent method or property is accessed.
inherited
-
toString()
→ String
-
A string representation of this object.
inherited
-
update(ServiceCall call, Subscription request)
→ Future<Subscription>
-
-
update_Pre(ServiceCall $call, Future<Subscription> $request)
→ Future<Subscription>
-