- Annotations
-
- @GrpcServiceName.new('UserService')
Properties
-
$name
→ String
-
no setter
-
hashCode
→ int
-
The hash code for this object.
no setterinherited
-
runtimeType
→ Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
$addMethod(ServiceMethod method)
→ void
-
inherited
-
$lookupMethod(String name)
→ ServiceMethod?
-
inherited
-
$onMetadata(ServiceCall context)
→ void
-
Client metadata handler.
inherited
-
createUser(ServiceCall call, AccountUser request)
→ Future<AccountUser>
-
-
createUser_Pre(ServiceCall $call, Future<AccountUser> $request)
→ Future<AccountUser>
-
-
deleteUser(ServiceCall call, AccountUserId request)
→ Future<Empty>
-
-
deleteUser_Pre(ServiceCall $call, Future<AccountUserId> $request)
→ Future<Empty>
-
-
getCurrentAccountId(ServiceCall call, UserId request)
→ Future<AccountAccess>
-
-
getCurrentAccountId_Pre(ServiceCall $call, Future<UserId> $request)
→ Future<AccountAccess>
-
-
getCurrentUser(ServiceCall call, AccountId request)
→ Future<AccountUserInfo>
-
-
getCurrentUser_Pre(ServiceCall $call, Future<AccountId> $request)
→ Future<AccountUserInfo>
-
-
getPrimaryContact(ServiceCall call, AccountId request)
→ Future<AccountUserInfo>
-
-
getPrimaryContact_Pre(ServiceCall $call, Future<AccountId> $request)
→ Future<AccountUserInfo>
-
-
getUser(ServiceCall call, AccountUserId request)
→ Future<AccountUserInfo>
-
-
getUser_Pre(ServiceCall $call, Future<AccountUserId> $request)
→ Future<AccountUserInfo>
-
-
listUsers(ServiceCall call, AccountUserQuery request)
→ Future<PageResult>
-
-
listUsers_Pre(ServiceCall $call, Future<AccountUserQuery> $request)
→ Future<PageResult>
-
-
noSuchMethod(Invocation invocation)
→ dynamic
-
Invoked when a nonexistent method or property is accessed.
inherited
-
toString()
→ String
-
A string representation of this object.
inherited
-
updateUser(ServiceCall call, AccountUser request)
→ Future<AccountUser>
-
-
updateUser_Pre(ServiceCall $call, Future<AccountUser> $request)
→ Future<AccountUser>
-