- Annotations
-
- @GrpcServiceName.new('VoucherService')
Properties
-
$name
→ String
-
no setter
-
hashCode
→ int
-
The hash code for this object.
no setterinherited
-
runtimeType
→ Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
$addMethod(ServiceMethod method)
→ void
-
inherited
-
$lookupMethod(String name)
→ ServiceMethod?
-
inherited
-
$onMetadata(ServiceCall context)
→ void
-
Client metadata handler.
inherited
-
claimVoucher(ServiceCall call, ClaimVoucherRequest request)
→ Future<ClaimVoucherResponse>
-
-
claimVoucher_Pre(ServiceCall $call, Future<ClaimVoucherRequest> $request)
→ Future<ClaimVoucherResponse>
-
-
create(ServiceCall call, Voucher request)
→ Future<Voucher>
-
-
create_Pre(ServiceCall $call, Future<Voucher> $request)
→ Future<Voucher>
-
-
delete(ServiceCall call, VoucherCode request)
→ Future<Empty>
-
-
delete_Pre(ServiceCall $call, Future<VoucherCode> $request)
→ Future<Empty>
-
-
get(ServiceCall call, VoucherCode request)
→ Future<Voucher>
-
-
get_Pre(ServiceCall $call, Future<VoucherCode> $request)
→ Future<Voucher>
-
-
getStatus(ServiceCall call, VoucherStatusRequest request)
→ Future<VoucherStatusResponse>
-
-
getStatus_Pre(ServiceCall $call, Future<VoucherStatusRequest> $request)
→ Future<VoucherStatusResponse>
-
-
list(ServiceCall call, VoucherQuery request)
→ Future<PageResult>
-
-
list_Pre(ServiceCall $call, Future<VoucherQuery> $request)
→ Future<PageResult>
-
-
listRules(ServiceCall call, VoucherRuleQuery request)
→ Future<PageResult>
-
-
listRules_Pre(ServiceCall $call, Future<VoucherRuleQuery> $request)
→ Future<PageResult>
-
-
noSuchMethod(Invocation invocation)
→ dynamic
-
Invoked when a nonexistent method or property is accessed.
inherited
-
toString()
→ String
-
A string representation of this object.
inherited
-
update(ServiceCall call, Voucher request)
→ Future<Voucher>
-
-
update_Pre(ServiceCall $call, Future<Voucher> $request)
→ Future<Voucher>
-