WebsiteServiceClient class
Configuration Service
- Annotations
-
- @GrpcServiceName.new('WebsiteService')
Constructors
-
WebsiteServiceClient(ClientChannel channel, {CallOptions? options, Iterable<
ClientInterceptor> ? interceptors})
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
$createCall<
Q, R> (ClientMethod< Q, R> method, Stream<Q> requests, {CallOptions? options}) → ClientCall<Q, R> -
inherited
-
$createStreamingCall<
Q, R> (ClientMethod< Q, R> method, Stream<Q> requests, {CallOptions? options}) → ResponseStream<R> -
inherited
-
$createUnaryCall<
Q, R> (ClientMethod< Q, R> method, Q request, {CallOptions? options}) → ResponseFuture<R> -
inherited
-
create(
Website request, {CallOptions? options}) → ResponseFuture< Website> -
deletePage(
WebsitePageId request, {CallOptions? options}) → ResponseFuture< WebsitePage> -
get(
WebsiteId request, {CallOptions? options}) → ResponseFuture< Website> -
getPage(
WebsitePageId request, {CallOptions? options}) → ResponseFuture< WebsitePage> -
list(
WebsiteQuery request, {CallOptions? options}) → ResponseFuture< PageResult> - Websites: List Websites WebsiteHeader
-
listPages(
WebsitePageQuery request, {CallOptions? options}) → ResponseFuture< PageResult> - Websites: List Pages WebsitePage
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
publish(
WebsiteId request, {CallOptions? options}) → ResponseFuture< AsyncOperationId> -
render(
WebsiteRenderRequest request, {CallOptions? options}) → ResponseFuture< WebsiteRenderResult> -
toString(
) → String -
A string representation of this object.
inherited
-
upsert(
Website request, {CallOptions? options}) → ResponseFuture< Website> -
upsertElement(
WebsiteEditorElement request, {CallOptions? options}) → ResponseFuture< WebsiteEditorElement> -
upsertPage(
WebsitePage request, {CallOptions? options}) → ResponseFuture< WebsitePage>
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- defaultHost → const String
- The hostname for this service.
-
oauthScopes
→ const List<
String> - OAuth scopes needed for the client.